@@ -64,7 +64,7 @@ our $VERSION = $ZoneMinder::Base::VERSION;
 # ==========================================================================
 
 use ZoneMinder::Config qw(:all);
-use ZoneMinder::Debug qw(:all);
+use ZoneMinder::Logger qw(:all);
 
 use Sys::Mmap;
 
