@@ -1,6 +1,6 @@
 # ==========================================================================
 #
-# ZoneMinder Trigger Channel Handle Module, $Date: 2008-07-25 02:48:16 -0700 (Fri, 25 Jul 2008) $, $Revision: 2612 $
+# ZoneMinder Trigger Channel Handle Module, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 # Copyright (C) 2001-2008  Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@ our $VERSION = $ZoneMinder::Base::VERSION;
 #
 # ==========================================================================
 
-use ZoneMinder::Debug qw(:all);
+use ZoneMinder::Logger qw(:all);
 use Device::SerialPort;
 
 sub new
