@@ -1,6 +1,6 @@
 # ==========================================================================
 #
-# ZoneMinder Trigger Connection Module, $Date: 2011-01-05 17:33:45 +0000 (Wed, 05 Jan 2011) $, $Revision: 3220 $
+# ZoneMinder Trigger Connection Module, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 # Copyright (C) 2001-2008  Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
@@ -38,7 +38,7 @@ our $VERSION = $ZoneMinder::Base::VERSION;
 #
 # ==========================================================================
 
-use ZoneMinder::Debug qw(:all);
+use ZoneMinder::Logger qw(:all);
 
 use Carp;
 
