@@ -1,6 +1,6 @@
 //
-// ZoneMinder Camera Class Implementation, $Date: 2006/04/12 15:14:55 $, $Revision: 1.6 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Camera Class Implementation, $Date: 2009-02-18 12:30:43 +0000 (Wed, 18 Feb 2009) $, $Revision: 2777 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -20,10 +20,19 @@
 #include "zm.h"
 #include "zm_camera.h"
 
-Camera::Camera( SourceType p_type, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) : type( p_type ), width( p_width), height( p_height ), palette( p_palette ), brightness( p_brightness ), contrast( p_contrast ), hue( p_hue ), colour( p_colour ), capture( p_capture )
+Camera::Camera( int p_id, SourceType p_type, int p_width, int p_height, int p_colours, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) :
+    id( p_id ),
+    type( p_type ),
+    width( p_width),
+    height( p_height ),
+    colours( p_colours ),
+    brightness( p_brightness ),
+    hue( p_hue ),
+    colour( p_colour ),
+    contrast( p_contrast ),
+    capture( p_capture )
 {
-	colours = (palette==VIDEO_PALETTE_GREY?1:3);
-	size = width * height * colours;
+	pixels = width * height * colours;
 }
 
 Camera::~Camera()
