@@ -1,6 +1,6 @@
 //
-// ZoneMinder Camera Class Interface, $Date: 2006-10-24 15:37:34 +0100 (Tue, 24 Oct 2006) $, $Revision: 2030 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Camera Class Interface, $Date: 2009-02-18 12:30:43 +0000 (Wed, 18 Feb 2009) $, $Revision: 2777 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -22,7 +22,6 @@
 
 #include <sys/types.h>
 #include <sys/ioctl.h>
-#include <linux/videodev.h>
 
 #include "zm_image.h"
 
@@ -33,44 +32,46 @@
 class Camera
 {
 protected:
-	typedef enum { LOCAL, REMOTE, FILE } SourceType;
+	typedef enum { LOCAL_SRC, REMOTE_SRC, FILE_SRC, FFMPEG_SRC } SourceType;
 
+    int             id;
 	SourceType		type;
 	unsigned int	width;
 	unsigned int	height;
-	unsigned int	palette;
 	unsigned int	colours;
-	unsigned int	size;
+	unsigned int	pixels;
 	int				brightness;
 	int				hue;
 	int				colour;
 	int				contrast;
-	bool			capture;
+    bool            capture;
 
 public:
-	Camera( SourceType p_type, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture=true );
+	Camera( int p_id, SourceType p_type, int p_width, int p_height, int p_colours, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture );
 	virtual ~Camera();
 
+    int getId() const { return( id ); }
 	SourceType Type() const { return( type ); }
-	bool IsLocal() const { return( type == LOCAL ); }
-	bool IsRemote() const { return( type == REMOTE ); }
-	bool IsFile() const { return( type == FILE ); }
+	bool IsLocal() const { return( type == LOCAL_SRC ); }
+	bool IsRemote() const { return( type == REMOTE_SRC ); }
+	bool IsFile() const { return( type == FILE_SRC ); }
+	bool IsFfmpeg() const { return( type == FFMPEG_SRC ); }
 	unsigned int Width() const { return( width ); }
 	unsigned int Height() const { return( height ); }
-	unsigned int Palette() const { return( palette ); }
 	unsigned int Colours() const { return( colours ); }
-	unsigned int ImageSize() const { return( size ); }
+	unsigned int ImageSize() const { return( pixels ); }
 
 	virtual int Brightness( int/*p_brightness*/=-1 ) { return( -1 ); }
 	virtual int Hue( int/*p_hue*/=-1 ) { return( -1 ); }
 	virtual int Colour( int/*p_colour*/=-1 ) { return( -1 ); }
 	virtual int Contrast( int/*p_contrast*/=-1 ) { return( -1 ); }
 
-	bool CanCapture() const { return( capture ); }
-
+    bool CanCapture() const { return( capture ); }
+    
 	virtual int PrimeCapture() { return( 0 ); }
 	virtual int PreCapture()=0;
-	virtual int PostCapture( Image &image )=0;
+	virtual int Capture( Image &image )=0;
+	virtual int PostCapture()=0;
 };
 
 #endif // ZM_CAMERA_H
