@@ -1,5 +1,5 @@
 //
-// ZoneMinder Communicatoions Class Interface, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// ZoneMinder Communicatoions Class Interface, $Date: 2009-07-01 13:28:40 +0100 (Wed, 01 Jul 2009) $, $Revision: 2942 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -320,7 +320,7 @@ public:
 	{
 		ssize_t nBytes = ::send( mSd, msg.data(), msg.size(), 0 );
         if ( nBytes < 0 )
-            Debug( 1, "Send of string '%s' (%d bytes) on sd %d failed: %s", msg.c_str(), msg.size(), mSd, strerror(errno) );
+            Debug( 1, "Send of string '%s' (%zd bytes) on sd %d failed: %s", msg.c_str(), msg.size(), mSd, strerror(errno) );
 		return( nBytes );
 	}
 	virtual int recv( std::string &msg ) const
@@ -329,7 +329,7 @@ public:
         int nBytes = 0;
 		if ( (nBytes = ::recv( mSd, buffer, sizeof(buffer), 0 )) < 0 )
         {
-            Debug( 1, "Recv of %d bytes max to string on sd %d failed: %s", sizeof(buffer), mSd, strerror(errno) );
+            Debug( 1, "Recv of %zd bytes max to string on sd %d failed: %s", sizeof(buffer), mSd, strerror(errno) );
             return( nBytes );
         }
         buffer[nBytes] = '\0';
@@ -342,7 +342,7 @@ public:
         int nBytes = 0;
 		if ( (nBytes = ::recv( mSd, buffer, sizeof(buffer), 0 )) < 0 )
         {
-            Debug( 1, "Recv of %d bytes max to string on sd %d failed: %s", maxLen, mSd, strerror(errno) );
+            Debug( 1, "Recv of %zd bytes max to string on sd %d failed: %s", maxLen, mSd, strerror(errno) );
             return( nBytes );
         }
         buffer[nBytes] = '\0';
