@@ -1,5 +1,5 @@
 //
-// ZoneMinder MySQL Implementation, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// ZoneMinder MySQL Implementation, $Date: 2011-08-23 14:31:04 +0100 (Tue, 23 Aug 2011) $, $Revision: 3499 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -25,13 +25,18 @@
 
 MYSQL dbconn;
 
+int zmDbConnected = false;
+
 void zmDbConnect()
 {
 	if ( !mysql_init( &dbconn ) )
 	{
-		Error( "Can't initialise structure: %s", mysql_error( &dbconn ) );
+		Error( "Can't initialise database connection: %s", mysql_error( &dbconn ) );
 		exit( mysql_errno( &dbconn ) );
 	}
+    my_bool reconnect = 1;
+    if ( mysql_options( &dbconn, MYSQL_OPT_RECONNECT, &reconnect ) )
+        Fatal( "Can't set database auto reconnect option: %s", mysql_error( &dbconn ) );
     std::string::size_type colonIndex = staticConfig.DB_HOST.find( ":/" );
     if ( colonIndex != std::string::npos )
     {
@@ -56,5 +61,6 @@ void zmDbConnect()
 		Error( "Can't select database: %s", mysql_error( &dbconn ) );
 		exit( mysql_errno( &dbconn ) );
 	}
+    zmDbConnected = true;
 }
 
