@@ -1,5 +1,5 @@
 //
-// ZoneMinder Core Interfaces, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// ZoneMinder Core Interfaces, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -22,10 +22,16 @@
 
 #include <mysql/mysql.h>
 
-#include "zm.h"
-
+#ifdef __cplusplus 
+extern "C" {
+#endif 
 extern MYSQL dbconn;
 
+extern int zmDbConnected;
+
 void zmDbConnect();
+#ifdef __cplusplus 
+} /* extern "C" */
+#endif 
 
 #endif // ZM_DB_H
