@@ -1,5 +1,5 @@
 //
-// ZoneMinder Event Class Implementation, $Date: 2009-05-08 14:47:19 +0100 (Fri, 08 May 2009) $, $Revision: 2867 $
+// ZoneMinder Event Class Implementation, $Date: 2010-11-11 12:22:35 +0000 (Thu, 11 Nov 2010) $, $Revision: 3189 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -60,7 +60,14 @@ Event::Event( Monitor *p_monitor, struct timeval p_start_time, const std::string
     std::string notes;
     createNotes( notes );
 
-    static char sql[BUFSIZ];
+    bool untimedEvent = false;
+    if ( !start_time.tv_sec )
+    {
+        untimedEvent = true;
+        gettimeofday( &start_time, 0 );
+    }
+
+    static char sql[ZM_SQL_MED_BUFSIZ];
 
     struct tm *stime = localtime( &start_time.tv_sec );
     snprintf( sql, sizeof(sql), "insert into Events ( MonitorId, Name, StartTime, Width, Height, Cause, Notes ) values ( %d, 'New Event', from_unixtime( %ld ), %d, %d, '%s', '%s' )", monitor->Id(), start_time.tv_sec, monitor->Width(), monitor->Height(), cause.c_str(), notes.c_str() );
@@ -70,6 +77,10 @@ Event::Event( Monitor *p_monitor, struct timeval p_start_time, const std::string
         exit( mysql_errno( &dbconn ) );
     }
     id = mysql_insert_id( &dbconn );
+    if ( untimedEvent )
+    {
+        Warning( "Event %d has zero time, setting to current", id );
+    }
     end_time.tv_sec = 0;
     frames = 0;
     alarm_frames = 0;
@@ -156,7 +167,7 @@ Event::~Event()
         DELTA_TIMEVAL( delta_time, end_time, start_time, DT_PREC_2 );
 
         Debug( 1, "Adding closing frame %d to DB", frames );
-        static char sql[BUFSIZ];
+        static char sql[ZM_SQL_SML_BUFSIZ];
         snprintf( sql, sizeof(sql), "insert into Frames ( EventId, FrameId, TimeStamp, Delta ) values ( %d, %d, from_unixtime( %ld ), %s%ld.%02ld )", id, frames, end_time.tv_sec, delta_time.positive?"":"-", delta_time.sec, delta_time.fsec );
         if ( mysql_query( &dbconn, sql ) )
         {
@@ -165,7 +176,7 @@ Event::~Event()
         }
     }
 
-    static char sql[BUFSIZ];
+    static char sql[ZM_SQL_MED_BUFSIZ];
 
     struct DeltaTimeval delta_time;
     DELTA_TIMEVAL( delta_time, end_time, start_time, DT_PREC_2 );
@@ -315,7 +326,7 @@ bool Event::SendFrameImage( const Image *image, bool alarm_frame )
         }
         else
         {
-            Error( "Incomplete frame write: %d of %d bytes written", writev_result, writev_size );
+            Error( "Incomplete frame write: %zd of %zd bytes written", writev_result, writev_size );
             close( sd );
             sd = -1;
         }
@@ -407,11 +418,11 @@ void Event::updateNotes( const StringSetMap &newNoteSetMap )
         createNotes( notes );
 
         Debug( 2, "Updating notes for event %d, '%s'", id, notes.c_str() );
-        static char sql[BUFSIZ];
+        static char sql[ZM_SQL_MED_BUFSIZ];
 #if USE_PREPARED_SQL
         static MYSQL_STMT *stmt = 0;
 
-        char notesStr[BUFSIZ] = "";
+        char notesStr[ZM_SQL_MED_BUFSIZ] = "";
         unsigned long notesLen = 0;
 
         if ( !stmt )
@@ -460,7 +471,7 @@ void Event::updateNotes( const StringSetMap &newNoteSetMap )
             Fatal( "Unable to execute sql '%s': %s", sql, mysql_stmt_error(stmt) );
         }
 #else
-        static char escapedNotes[BUFSIZ];
+        static char escapedNotes[ZM_SQL_MED_BUFSIZ];
 
         mysql_real_escape_string( &dbconn, escapedNotes, notes.c_str(), notes.length() );
 
@@ -475,10 +486,17 @@ void Event::updateNotes( const StringSetMap &newNoteSetMap )
 
 void Event::AddFrames( int n_frames, Image **images, struct timeval **timestamps )
 {
-    static char sql[BUFSIZ];
-    strncpy( sql, "insert into Frames ( EventId, FrameId, TimeStamp, Delta ) values ", BUFSIZ );
+    static char sql[ZM_SQL_LGE_BUFSIZ];
+    strncpy( sql, "insert into Frames ( EventId, FrameId, TimeStamp, Delta ) values ", sizeof(sql) );
+    int frameCount = 0;
     for ( int i = 0; i < n_frames; i++ )
     {
+        if ( !timestamps[i]->tv_sec )
+        {
+            Debug( 1, "Not adding pre-capture frame %d, zero timestamp", i );
+            continue;
+        }
+
         frames++;
 
         static char event_file[PATH_MAX];
@@ -492,21 +510,35 @@ void Event::AddFrames( int n_frames, Image **images, struct timeval **timestamps
 
         int sql_len = strlen(sql);
         snprintf( sql+sql_len, sizeof(sql)-sql_len, "( %d, %d, from_unixtime(%ld), %s%ld.%02ld ), ", id, frames, timestamps[i]->tv_sec, delta_time.positive?"":"-", delta_time.sec, delta_time.fsec );
+
+        frameCount++;
     }
 
-    Debug( 1, "Adding %d frames to DB", n_frames );
-    *(sql+strlen(sql)-2) = '\0';
-    if ( mysql_query( &dbconn, sql ) )
+    if ( frameCount )
     {
-        Error( "Can't insert frames: %s", mysql_error( &dbconn ) );
-        exit( mysql_errno( &dbconn ) );
+        Debug( 1, "Adding %d/%d frames to DB", frameCount, n_frames );
+        *(sql+strlen(sql)-2) = '\0';
+        if ( mysql_query( &dbconn, sql ) )
+        {
+            Error( "Can't insert frames: %s", mysql_error( &dbconn ) );
+            exit( mysql_errno( &dbconn ) );
+        }
+        last_db_frame = frames;
+    }
+    else
+    {
+        Debug( 1, "No valid pre-capture frames to add" );
     }
-
-    last_db_frame = frames;
 }
 
 void Event::AddFrame( Image *image, struct timeval timestamp, int score, Image *alarm_image )
 {
+    if ( !timestamp.tv_sec )
+    {
+        Debug( 1, "Not adding new frame, zero timestamp" );
+        return;
+    }
+
     frames++;
 
     static char event_file[PATH_MAX];
@@ -525,7 +557,7 @@ void Event::AddFrame( Image *image, struct timeval timestamp, int score, Image *
         const char *frame_type = score>0?"Alarm":(score<0?"Bulk":"Normal");
 
         Debug( 1, "Adding frame %d to DB", frames );
-        static char sql[BUFSIZ];
+        static char sql[ZM_SQL_MED_BUFSIZ];
         snprintf( sql, sizeof(sql), "insert into Frames ( EventId, FrameId, Type, TimeStamp, Delta, Score ) values ( %d, %d, '%s', from_unixtime( %ld ), %s%ld.%02ld, %d )", id, frames, frame_type, timestamp.tv_sec, delta_time.positive?"":"-", delta_time.sec, delta_time.fsec, score );
         if ( mysql_query( &dbconn, sql ) )
         {
@@ -609,7 +641,7 @@ void Event::AddFrame( Image *image, struct timeval timestamp, int score, Image *
 
 bool EventStream::loadInitialEventData( int monitor_id, time_t event_time )
 {
-    static char sql[BUFSIZ];
+    static char sql[ZM_SQL_SML_BUFSIZ];
 
     snprintf( sql, sizeof(sql), "select Id from Events where MonitorId = %d and unix_timestamp( EndTime ) > %ld order by Id asc limit 1", monitor_id, event_time );
 
@@ -681,7 +713,7 @@ bool EventStream::loadInitialEventData( int init_event_id, int init_frame_id )
 
 bool EventStream::loadEventData( int event_id )
 {
-    static char sql[BUFSIZ];
+    static char sql[ZM_SQL_MED_BUFSIZ];
 
     snprintf( sql, sizeof(sql), "select M.Id, M.Name, E.Frames, unix_timestamp( StartTime ) as StartTimestamp, max(F.Delta)-min(F.Delta) as Duration from Events as E inner join Monitors as M on E.MonitorId = M.Id inner join Frames as F on E.Id = F.EventId where E.Id = %d group by E.Id", event_id );
 
@@ -723,7 +755,10 @@ bool EventStream::loadEventData( int event_id )
     }
     else
     {
-        snprintf( event_data->path, sizeof(event_data->path), "%s/%s/%ld/%ld", staticConfig.PATH_WEB.c_str(), config.dir_events, event_data->monitor_id, event_data->event_id );
+        if ( config.dir_events[0] == '/' )
+            snprintf( event_data->path, sizeof(event_data->path), "%s/%ld/%ld", config.dir_events, event_data->monitor_id, event_data->event_id );
+        else
+            snprintf( event_data->path, sizeof(event_data->path), "%s/%s/%ld/%ld", staticConfig.PATH_WEB.c_str(), config.dir_events, event_data->monitor_id, event_data->event_id );
     }
     event_data->frame_count = atoi(dbrow[2]);
     event_data->duration = atof(dbrow[4]);
@@ -1071,7 +1106,7 @@ void EventStream::processCommand( const CmdMsg *msg )
 void EventStream::checkEventLoaded()
 {
     bool reload_event = false;
-    static char sql[BUFSIZ];
+    static char sql[ZM_SQL_SML_BUFSIZ];
 
     if ( curr_frame_id <= 0 )
     {
