@@ -1,6 +1,6 @@
 //
-// ZoneMinder File Camera Class Implementation, $Date: 2006-01-21 17:58:46 +0000 (Sat, 21 Jan 2006) $, $Revision: 1849 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder File Camera Class Implementation, $Date: 2009-01-28 09:48:06 +0000 (Wed, 28 Jan 2009) $, $Revision: 2724 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -34,7 +34,7 @@
 #include "zm.h"
 #include "zm_file_camera.h"
 
-FileCamera::FileCamera( const char *p_path, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) : Camera( FILE, p_width, p_height, p_palette, p_brightness, p_contrast, p_hue, p_colour, p_capture )
+FileCamera::FileCamera( int p_id, const char *p_path, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) : Camera( p_id, FILE_SRC, p_width, p_height, p_palette, p_brightness, p_contrast, p_hue, p_colour, p_capture )
 {
 	strncpy( path, p_path, sizeof(path) );
 	if ( capture )
@@ -55,7 +55,7 @@ void FileCamera::Initialise()
 {
 	if ( !path[0] )
 	{
-		Error(( "No path specified for file image" ));
+		Error( "No path specified for file image" );
 		exit( -1 );
 	}
 }
@@ -69,7 +69,7 @@ int FileCamera::PreCapture()
 	struct stat statbuf;
 	if ( stat( path, &statbuf ) < 0 )
 	{
-		Error(( "Can't stat %s: %s", path, strerror(errno) ));
+		Error( "Can't stat %s: %s", path, strerror(errno) );
 		return( -1 );
 	}
 
@@ -80,7 +80,12 @@ int FileCamera::PreCapture()
 	return( 0 );
 }
 
-int FileCamera::PostCapture( Image &image )
+int FileCamera::Capture( Image &image )
 {
 	return( image.ReadJpeg( path )?0:-1 );
 }
+
+int FileCamera::PostCapture()
+{
+    return( 0 );
+}
