@@ -1,5 +1,5 @@
 //
-// ZoneMinder Image Class Implementation, $Date: 2011-02-15 11:18:41 +0000 (Tue, 15 Feb 2011) $, $Revision: 3301 $
+// ZoneMinder Image Class Implementation, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -1365,7 +1365,7 @@ void Image::Fill( Rgb colour, int density, const Polygon &polygon )
 	qsort( global_edges, n_global_edges, sizeof(*global_edges), Edge::CompareYX );
 
 #ifndef ZM_DBG_OFF
-	if ( zmDbgLevel >= 9 )
+	if ( logLevel() >= Logger::DEBUG9 )
 	{
 		for ( int i = 0; i < n_global_edges; i++ )
 		{
@@ -1400,7 +1400,7 @@ void Image::Fill( Rgb colour, int density, const Polygon &polygon )
 		}
 		qsort( active_edges, n_active_edges, sizeof(*active_edges), Edge::CompareX );
 #ifndef ZM_DBG_OFF
-		if ( zmDbgLevel >= 9 )
+	    if ( logLevel() >= Logger::DEBUG9 )
 		{
 			for ( int i = 0; i < n_active_edges; i++ )
 			{
