@@ -1,5 +1,5 @@
 //
-// ZoneMinder Image Class Interface, $Date: 2009-03-20 12:39:29 +0000 (Fri, 20 Mar 2009) $, $Revision: 2809 $
+// ZoneMinder Image Class Interface, $Date: 2011-02-15 11:18:41 +0000 (Tue, 15 Feb 2011) $, $Revision: 3301 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -41,8 +41,6 @@ extern "C"
 class Image
 {
 protected:
-	enum { CHAR_HEIGHT=11, CHAR_WIDTH=6 };
-    enum { LINE_HEIGHT=CHAR_HEIGHT+0 };
 	typedef unsigned char BlendTable[256][256];
 	typedef BlendTable *BlendTablePtr;
 
@@ -68,6 +66,10 @@ protected:
 		}
 	};
 
+public:
+	enum { CHAR_HEIGHT=11, CHAR_WIDTH=6 };
+    enum { LINE_HEIGHT=CHAR_HEIGHT+0 };
+
 protected:
 	static bool initialised;
 	static unsigned char *abs_table;
@@ -86,12 +88,12 @@ protected:
 	int colours;
 	int size;
     int allocation;
-	JSAMPLE *buffer;
+	uint8_t *buffer;
 	bool our_buffer;
 	char text[1024];
 
 protected:
-	mutable unsigned int *blend_buffer;
+	mutable uint16_t *blend_buffer;
 
 protected:
 	static void Initialise();
@@ -100,7 +102,7 @@ protected:
 public:
 	Image();
 	Image( const char *filename );
-	Image( int p_width, int p_height, int p_colours, JSAMPLE *p_buffer=0 );
+	Image( int p_width, int p_height, int p_colours, uint8_t *p_buffer=0 );
 	Image( const Image &p_image );
 	~Image();
 
@@ -109,8 +111,8 @@ public:
 	inline int Pixels() const { return( pixels ); }
 	inline int Colours() const { return( colours ); }
 	inline int Size() const { return( size ); }
-	inline JSAMPLE *Buffer() const { return( buffer ); }
-	inline JSAMPLE *Buffer( unsigned int x, unsigned int y= 0 ) const { return( &buffer[colours*((y*width)+x)] ); }
+	inline uint8_t *Buffer() const { return( buffer ); }
+	inline uint8_t *Buffer( unsigned int x, unsigned int y= 0 ) const { return( &buffer[colours*((y*width)+x)] ); }
 	
     void Empty();
 	void Assign( int p_width, int p_height, int p_colours, unsigned char *new_buffer );
@@ -120,7 +122,7 @@ public:
 	{
 		if ( image.size != size )
         {
-            Fatal( "Attempt to copy different size image buffers, expected %d, got %d", size, image.size );
+            Panic( "Attempt to copy different size image buffers, expected %d, got %d", size, image.size );
         }
 		memcpy( buffer, image.buffer, size );
 	}
