@@ -1,5 +1,5 @@
 /*
- * ZoneMinder Jpeg Interface, $Date: 2010-01-20 14:43:54 +0000 (Wed, 20 Jan 2010) $, $Revision: 3012 $
+ * ZoneMinder Jpeg Interface, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
  * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
@@ -23,6 +23,12 @@
 #include "jpeglib.h"
 #include "jerror.h"
 
+// Stop complaints about deuplicate definitions
+#undef HAVE_STDLIB_H
+#undef HAVE_STDDEF_H
+
+extern "C"
+{
 /* Stuff for overriden error handlers */
 struct zm_error_mgr
 {
@@ -38,3 +44,4 @@ void zm_jpeg_emit_message( j_common_ptr cinfo, int msg_level );
 // Prototypes for memory compress/decompression object */
 void zm_jpeg_mem_src(j_decompress_ptr cinfo, const JOCTET *inbuffer, int inbuffer_size );
 void zm_jpeg_mem_dest(j_compress_ptr cinfo, JOCTET *outbuffer, int *outbuffer_size );
+}
