@@ -1,5 +1,5 @@
 //
-// ZoneMinder Local Camera Class Implementation, $Date: 2011-02-17 09:31:33 +0000 (Thu, 17 Feb 2011) $, $Revision: 3304 $
+// ZoneMinder Local Camera Class Implementation, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -337,7 +337,7 @@ LocalCamera::~LocalCamera()
 void LocalCamera::Initialise()
 {
 #if HAVE_LIBSWSCALE
-    if ( zmDbgLevel > ZM_DBG_INF )
+    if ( logDebugging() )
         av_log_set_level( AV_LOG_DEBUG );
     else
         av_log_set_level( AV_LOG_QUIET );
