@@ -1,5 +1,5 @@
 //
-// ZoneMinder Local Camera Class Interface, $Date: 2009-03-31 13:57:34 +0100 (Tue, 31 Mar 2009) $, $Revision: 2827 $
+// ZoneMinder Local Camera Class Interface, $Date: 2011-02-15 21:59:06 +0000 (Tue, 15 Feb 2011) $, $Revision: 3302 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -23,15 +23,16 @@
 #include "zm.h"
 #include "zm_camera.h"
 
-#include "zm_ffmpeg.h"
+#if ZM_HAS_V4L
 
-#ifdef HAVE_LINUX_VIDEODEV2_H
-#include <linux/videodev2.h>
-#define ZM_V4L2
-#endif // HAVE_LINUX_VIDEODEV2_H
 #ifdef HAVE_LINUX_VIDEODEV_H
 #include <linux/videodev.h>
 #endif // HAVE_LINUX_VIDEODEV_H
+#ifdef HAVE_LINUX_VIDEODEV2_H
+#include <linux/videodev2.h>
+#endif // HAVE_LINUX_VIDEODEV2_H
+
+#include "zm_ffmpeg.h"
 
 //
 // Class representing 'local' cameras, i.e. those which are
@@ -41,7 +42,7 @@
 class LocalCamera : public Camera
 {
 protected:
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     struct V4L2MappedBuffer
     {
         void    *start;
@@ -57,8 +58,9 @@ protected:
         V4L2MappedBuffer    *buffers;
         v4l2_buffer         *bufptr;
     };
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
 
+#if ZM_HAS_V4L1
     struct V4L1Data
     {
 	    int				    active_frame;
@@ -66,6 +68,7 @@ protected:
 	    video_mmap		    *buffers;
 	    unsigned char	    *bufptr;
     };
+#endif // ZM_HAS_V4L1
 
 protected:
 	std::string             device;
@@ -87,10 +90,12 @@ protected:
 
     static int              v4l_version;
 
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     static V4L2Data         v4l2_data;
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     static V4L1Data         v4l1_data;
+#endif // ZM_HAS_V4L1
 
 #if HAVE_LIBSWSCALE
     PixelFormat             imagePixFormat;
@@ -133,4 +138,6 @@ public:
 	static bool GetCurrentSettings( const char *device, char *output, int version, bool verbose );
 };
 
+#endif // ZM_HAS_V4L
+
 #endif // ZM_LOCAL_CAMERA_H
