@@ -1,5 +1,5 @@
 //
-// ZoneMinder Monitor Class Interfaces, $Date: 2009-03-23 21:56:30 +0000 (Mon, 23 Mar 2009) $, $Revision: 2811 $
+// ZoneMinder Monitor Class Interfaces, $Date: 2011-02-15 21:59:06 +0000 (Tue, 15 Feb 2011) $, $Revision: 3302 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -355,7 +355,9 @@ public:
 	bool DumpSettings( char *output, bool verbose );
 	void DumpZoneImage( const char *zone_string=0 );
 
+#if ZM_HAS_V4L
 	static int LoadLocalMonitors( const char *device, Monitor **&monitors, Purpose purpose );
+#endif // ZM_HAS_V4L
 	static int LoadRemoteMonitors( const char *protocol, const char *host, const char*port, const char*path, Monitor **&monitors, Purpose purpose );
 	static int LoadFileMonitors( const char *file, Monitor **&monitors, Purpose purpose );
 #if HAVE_LIBAVFORMAT
