@@ -1,5 +1,5 @@
 /*
- * ZoneMinder MPEG Interface, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+ * ZoneMinder MPEG Interface, $Date: 2009-05-08 14:47:19 +0100 (Fri, 08 May 2009) $, $Revision: 2867 $
  * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
@@ -54,11 +54,11 @@ protected:
 	static void Initialise();
 
 	void SetupFormat( const char *p_filename, const char *format );
-	void SetupCodec( int colours, int width, int height, int bitrate, int frame_rate );
+	void SetupCodec( int colours, int width, int height, int bitrate, double frame_rate );
 	void SetParameters();
 
 public:
-	VideoStream( const char *filename, const char *format, int bitrate, int frame_rate, int colours, int width, int height );
+	VideoStream( const char *filename, const char *format, int bitrate, double frame_rate, int colours, int width, int height );
 	~VideoStream();
 	const char *MimeType() const;
 	void OpenStream();
