@@ -1,5 +1,5 @@
 //
-// ZoneMinder RTSP Class Implementation, $Date: 2011-05-15 21:38:51 +0100 (Sun, 15 May 2011) $, $Revision: 3338 $
+// ZoneMinder RTSP Class Implementation, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -83,7 +83,7 @@ bool RtspThread::recvResponse( std::string &response )
         {
             Error( "Response parse failure, %zd bytes follow", response.size() );
             if ( response.size() )
-                Hexdump( ZM_DBG_ERR, response.data(), min(response.size(),16) );
+                Hexdump( Logger::ERROR, response.data(), min(response.size(),16) );
         }
         return( false );
     }
@@ -257,7 +257,7 @@ int RtspThread::run()
             {
                 Error( "Response parse failure, %zd bytes follow", response.size() );
                 if ( response.size() )
-                    Hexdump( ZM_DBG_ERR, response.data(), min(response.size(),16) );
+                    Hexdump( Logger::ERROR, response.data(), min(response.size(),16) );
             }
             return( -1 );
         }
