@@ -23,6 +23,44 @@
 
 #include "zm_sdp.h"
 
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,2,1)
+SessionDescriptor::StaticPayloadDesc SessionDescriptor::smStaticPayloads[] = {
+    { 0, "PCMU",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_PCM_MULAW,  8000,  1 },
+    { 3, "GSM",    AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
+    { 4, "G723",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
+    { 5, "DVI4",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
+    { 6, "DVI4",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       16000, 1 },
+    { 7, "LPC",    AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
+    { 8, "PCMA",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_PCM_ALAW,   8000,  1 },
+    { 9, "G722",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
+    { 10, "L16",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_PCM_S16BE,  44100, 2 },
+    { 11, "L16",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_PCM_S16BE,  44100, 1 },
+    { 12, "QCELP", AVMEDIA_TYPE_AUDIO,   CODEC_ID_QCELP,      8000,  1 },
+    { 13, "CN",    AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
+    { 14, "MPA",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_MP2,        -1,    -1 },
+    { 14, "MPA",   AVMEDIA_TYPE_AUDIO,   CODEC_ID_MP3,        -1,    -1 },
+    { 15, "G728",  AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
+    { 16, "DVI4",  AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       11025, 1 },
+    { 17, "DVI4",  AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       22050, 1 },
+    { 18, "G729",  AVMEDIA_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
+    { 25, "CelB",  AVMEDIA_TYPE_VIDEO,   CODEC_ID_NONE,       90000, -1 },
+    { 26, "JPEG",  AVMEDIA_TYPE_VIDEO,   CODEC_ID_MJPEG,      90000, -1 },
+    { 28, "nv",    AVMEDIA_TYPE_VIDEO,   CODEC_ID_NONE,       90000, -1 },
+    { 31, "H261",  AVMEDIA_TYPE_VIDEO,   CODEC_ID_H261,       90000, -1 },
+    { 32, "MPV",   AVMEDIA_TYPE_VIDEO,   CODEC_ID_MPEG1VIDEO, 90000, -1 },
+    { 32, "MPV",   AVMEDIA_TYPE_VIDEO,   CODEC_ID_MPEG2VIDEO, 90000, -1 },
+    { 33, "MP2T",  AVMEDIA_TYPE_DATA,    CODEC_ID_MPEG2TS,    90000, -1 },
+    { 34, "H263",  AVMEDIA_TYPE_VIDEO,   CODEC_ID_H263,       90000, -1 },
+    { -1, "",      AVMEDIA_TYPE_UNKNOWN, CODEC_ID_NONE,       -1,    -1 }
+};
+
+SessionDescriptor::DynamicPayloadDesc SessionDescriptor::smDynamicPayloads[] = {
+    { "MP4V-ES", AVMEDIA_TYPE_VIDEO, CODEC_ID_MPEG4 },
+    { "mpeg4-generic", AVMEDIA_TYPE_AUDIO, CODEC_ID_AAC },
+    { "H264", AVMEDIA_TYPE_VIDEO, CODEC_ID_H264 },
+    { "AMR", AVMEDIA_TYPE_AUDIO, CODEC_ID_AMR_NB }
+};
+#else
 SessionDescriptor::StaticPayloadDesc SessionDescriptor::smStaticPayloads[] = {
     { 0, "PCMU",   CODEC_TYPE_AUDIO,   CODEC_ID_PCM_MULAW,  8000,  1 },
     { 3, "GSM",    CODEC_TYPE_AUDIO,   CODEC_ID_NONE,       8000,  1 },
@@ -59,6 +97,7 @@ SessionDescriptor::DynamicPayloadDesc SessionDescriptor::smDynamicPayloads[] = {
     { "H264", CODEC_TYPE_VIDEO, CODEC_ID_H264 },
     { "AMR", CODEC_TYPE_AUDIO, CODEC_ID_AMR_NB }
 };
+#endif
 
 SessionDescriptor::ConnInfo::ConnInfo( const std::string &connInfo ) :
     mTtl( 16 ),
@@ -291,11 +330,6 @@ AVFormatContext *SessionDescriptor::generateFormatContext() const
 
     strncpy( formatContext->filename, mUrl.c_str(), sizeof(formatContext->filename) );
 
-    if ( mName.length() )
-        strncpy( formatContext->title, mName.c_str(), sizeof(formatContext->title) );
-    if ( mInfo.length() )
-        strncpy( formatContext->comment, mInfo.c_str(), sizeof(formatContext->comment) );
-
     //formatContext->nb_streams = mMediaList.size();
     for ( int i = 0; i < mMediaList.size(); i++ )
     {
@@ -303,10 +337,17 @@ AVFormatContext *SessionDescriptor::generateFormatContext() const
         AVStream *stream = av_new_stream( formatContext, i );
 
         Debug( 1, "Looking for codec for %s payload type %d / %s",  mediaDesc->getType().c_str(), mediaDesc->getPayloadType(), mediaDesc->getPayloadDesc().c_str() );
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,2,1)
+        if ( mediaDesc->getType() == "video" )
+            stream->codec->codec_type = AVMEDIA_TYPE_VIDEO;
+        else if ( mediaDesc->getType() == "audio" )
+            stream->codec->codec_type = AVMEDIA_TYPE_AUDIO;
+#else
         if ( mediaDesc->getType() == "video" )
             stream->codec->codec_type = CODEC_TYPE_VIDEO;
         else if ( mediaDesc->getType() == "audio" )
             stream->codec->codec_type = CODEC_TYPE_AUDIO;
+#endif
 
         if ( mediaDesc->getPayloadType() < PAYLOAD_TYPE_DYNAMIC )
         {
