@@ -1,5 +1,5 @@
 //
-// ZoneMinder Signal Handling Implementation, $Date: 2009-10-14 14:10:14 +0100 (Wed, 14 Oct 2009) $, $Revision: 2976 $
+// ZoneMinder Signal Handling Implementation, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -17,12 +17,13 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // 
 
-#include <string.h>
-#include <stdlib.h>
-
 #include "zm.h"
 #include "zm_signal.h"
 
+#include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
+
 bool zm_reload = false;
 
 RETSIGTYPE zm_hup_handler( int signal )
@@ -114,7 +115,7 @@ RETSIGTYPE zm_die_handler( int signal )
     }
     else
     {
-        cmd_ptr += snprintf( cmd_ptr, sizeof(cmd)-(cmd_ptr-cmd), "/path/to/%s", zmDbgName() );
+        cmd_ptr += snprintf( cmd_ptr, sizeof(cmd)-(cmd_ptr-cmd), "/path/to/%s", logId().c_str() );
     }
 	// skip first stack frame (points here)
 	for ( int i=1; i < trace_size; i++ )
