@@ -1,5 +1,5 @@
 //
-// ZoneMinder Thread Class Implementation, $Date: 2009-06-03 09:10:02 +0100 (Wed, 03 Jun 2009) $, $Revision: 2906 $
+// ZoneMinder Thread Class Implementation, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 
 #include "zm_thread.h"
 
-#include "zm_debug.h"
+#include "zm_logger.h"
 #include "zm_utils.h"
 
 #include <string.h>
