@@ -1,5 +1,5 @@
 /*
- * ZoneMinder regular expression class implementation, $Date: 2010-11-11 12:22:35 +0000 (Thu, 11 Nov 2010) $, $Revision: 3189 $
+ * ZoneMinder regular expression class implementation, $Date: 2011-08-03 12:31:06 +0100 (Wed, 03 Aug 2011) $, $Revision: 3489 $
  * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
@@ -17,16 +17,16 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */ 
 
-#include <string.h>
-#include <stdlib.h>
-#include <time.h>
-#include <ctype.h>
-
 #include "zm.h"
 #include "zm_db.h"
 
 #include "zm_user.h"
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
+
 User::User()
 {
 	username[0] = password[0] = 0;
@@ -66,14 +66,10 @@ User::User( MYSQL_ROW &dbrow )
 			{
 				monitor_ids[n_monitor_ids++] = id;
 				if ( !*ptr )
-				{
 					break;
-				}
 			}
 			while ( !isdigit( *ptr ) )
-			{
 				ptr++;
-			}
 		} while( *ptr );
 		monitor_ids[n_monitor_ids] = 0;
 	}
