@@ -1,5 +1,5 @@
 //
-// ZoneMinder Image File Writer Implementation, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// ZoneMinder Image File Writer Implementation, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -104,6 +104,8 @@ void Usage()
 
 int main( int argc, char *argv[] )
 {
+    srand( getpid() * time( 0 ) );
+
 	int id = -1;
 
 	static struct option long_options[] = {
@@ -153,13 +155,13 @@ int main( int argc, char *argv[] )
 		exit( 0 );
 	}
 
-	char dbg_id_string[16];
-	snprintf( dbg_id_string, sizeof(dbg_id_string), "m%d", id );
-
-	zmDbgInit( "zmf", dbg_id_string, 0 );
+	char log_id_string[16];
+	snprintf( log_id_string, sizeof(log_id_string), "m%d", id );
 
 	zmLoadConfig();
 
+	logInit( "zmf" );
+
 	Monitor *monitor = Monitor::Load( id, false, Monitor::QUERY );
 
 	if ( !monitor )
