@@ -1,5 +1,5 @@
 //
-// ZoneMinder Streaming Server, $Date: 2009-05-25 19:03:46 +0100 (Mon, 25 May 2009) $, $Revision: 2890 $
+// ZoneMinder Streaming Server, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -85,10 +85,10 @@ int main( int argc, const char *argv[] )
 		nph = true;
 	}
 	
-	zmDbgInit( "zms", "", 0 );
-
 	zmLoadConfig();
 
+	logInit( "zms" );
+
 	zmSetDefaultTermHandler();
 	zmSetDefaultDieHandler();
 
