@@ -1,5 +1,5 @@
 //
-// ZoneMinder Control Utility, $Date: 2011-02-15 21:59:06 +0000 (Tue, 15 Feb 2011) $, $Revision: 3302 $
+// ZoneMinder Control Utility, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -349,10 +349,10 @@ int main( int argc, char *argv[] )
 	}
 	//printf( "Monitor %d, Function %d\n", mon_id, function );
 
-	zmDbgInit( "zmu", "", -1 );
-
 	zmLoadConfig();
 
+	logInit( "zmu" );
+
 	zmSetDefaultTermHandler();
 	zmSetDefaultDieHandler();
 
