@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web action file, $Date: 2011-05-23 17:18:18 +0100 (Mon, 23 May 2011) $, $Revision: 3357 $
+// ZoneMinder web action file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -181,7 +181,7 @@ if ( !empty($action) )
                 $socket = socket_create( AF_UNIX, SOCK_STREAM, 0 );
                 if ( $socket < 0 )
                 {
-                    die( "socket_create() failed: ".socket_strerror($socket) );
+                    Fatal( "socket_create() failed: ".socket_strerror($socket) );
                 }
                 $sockFile = ZM_PATH_SOCKS.'/zmcontrol-'.$monitor['Id'].'.sock';
                 if ( @socket_connect( $socket, $sockFile ) )
@@ -197,7 +197,7 @@ if ( !empty($action) )
                     $optionString = jsonEncode( $options );
                     if ( !socket_write( $socket, $optionString ) )
                     {
-                        die( "Can't write to control socket: ".socket_strerror(socket_last_error($socket)) );
+                        Fatal( "Can't write to control socket: ".socket_strerror(socket_last_error($socket)) );
                     }
                     socket_close( $socket );
                 }
@@ -754,10 +754,10 @@ if ( !empty($action) )
                     case "web" :
                     case "tools" :
                         break;
-                    case "debug" :
+                    case "logging" :
                     case "network" :
                     case "mail" :
-                    case "ftp" :
+                    case "upload" :
                         $restartWarning = true;
                         break;
                     case "highband" :
