@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder main web interface file, $Date: 2009-11-19 08:13:07 +0000 (Thu, 19 Nov 2009) $, $Revision: 2990 $
+// ZoneMinder main web interface file, $Date: 2011-07-22 09:37:01 +0100 (Fri, 22 Jul 2011) $, $Revision: 3483 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -68,7 +68,7 @@ define( "ZM_SKIN_PATH", "skins/$skin" );
 
 $skinBase = array(); // To allow for inheritance of skins
 if ( !file_exists( ZM_SKIN_PATH ) )
-    die( "Invalid skin '$skin'" );
+    Fatal( "Invalid skin '$skin'" );
 require_once( ZM_SKIN_PATH.'/includes/init.php' );
 $skinBase[] = $skin;
 
@@ -83,6 +83,7 @@ if ( !isset($_SESSION['skin']) || isset($_REQUEST['skin']) )
 }
 
 require_once( 'includes/config.php' );
+require_once( 'includes/logger.php' );
 
 if ( ZM_OPT_USE_AUTH )
     if ( isset( $_SESSION['user'] ) )
@@ -96,10 +97,13 @@ require_once( 'includes/lang.php' );
 require_once( 'includes/functions.php' );
 
 if ( isset($_REQUEST['view']) )
-    $view = validHtmlStr($_REQUEST['view']);
+    $view = detaintPath($_REQUEST['view']);
+
+if ( isset($_REQUEST['request']) )
+    $request = detaintPath($_REQUEST['request']);
 
 if ( isset($_REQUEST['action']) )
-    $action = validHtmlStr($_REQUEST['action']);
+    $action = detaintPath($_REQUEST['action']);
 
 require_once( 'includes/actions.php' );
 
@@ -108,14 +112,10 @@ foreach ( getSkinIncludes( 'skin.php' ) as $includeFile )
 
 if ( isset( $_REQUEST['request'] ) )
 {
-    $request = validHtmlStr($_REQUEST['request']);
     foreach ( getSkinIncludes( 'ajax/'.$request.'.php', true, true ) as $includeFile )
     {
         if ( !file_exists( $includeFile ) )
-        {
-            error_log( "Request '$request' does not exist" );
-            die( "Request '$request' does not exist" );
-        }
+            Fatal( "Request '$request' does not exist" );
         require_once $includeFile;
     }
     return;
@@ -127,10 +127,7 @@ else
         foreach ( $includeFiles as $includeFile )
         {
             if ( !file_exists( $includeFile ) )
-            {
-                error_log( "View '$view' does not exist" );
-                die( "View '$view' does not exist" );
-            }
+                Fatal( "View '$view' does not exist" );
             require_once $includeFile;
         }
     }
