@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Chinese Traditional language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web Chinese Traditional language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -207,10 +207,14 @@ $SLANG = array(
     'CheckMethod'          => 'Alarm Check Method',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Choose Filter',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Choose Preset',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => '關閉',
     'Colour'               => 'Colour',
     'Command'              => 'Command',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Config',
     'ConfiguredFor'        => '配置為',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
@@ -230,6 +234,7 @@ $SLANG = array(
     'Controllable'         => 'Controllable',
     'Cycle'                => '分區輪流檢視',
     'CycleWatch'           => '分區輪流檢視',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => '日',
     'Debug'                => 'debug',
     'DefaultRate'          => '預設速率',
@@ -251,6 +256,7 @@ $SLANG = array(
     'DisableAlarms'        => '取消警報',
     'Disk'                 => '磁碟',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
     'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -288,6 +294,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'Zip',
     'ExportFrames'         => '輸出框架細項',
     'ExportImageFiles'     => '輸出圖片檔',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => '輸出其他檔(若有)',
     'ExportOptions'        => '輸出選項',
     'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
@@ -363,16 +370,21 @@ $SLANG = array(
     'Language'             => '語言',
     'Last'                 => 'Last',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'results only;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Limit to first', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Linked Monitors',
     'List'                 => '列出',
     'Load'                 => '載入',
     'Local'                => 'Local',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => '登入名稱',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => '登入中... 請稍後...',
     'Login'                => '登入',
     'Logout'               => '登出',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => '低',
     'LowBW'                => 'Low&nbsp;B/W',
     'Main'                 => 'Main',
@@ -406,6 +418,7 @@ $SLANG = array(
     'MaximumFPS'           => '最大每秒框架數 fps',
     'Medium'               => '中',
     'MediumBW'             => 'Medium&nbsp;B/W',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
     'MinBlobAreaLtMax'     => 'Minimum blob area should be less than maximum',
@@ -449,6 +462,7 @@ $SLANG = array(
     'Monitors'             => '監視',
     'Montage'              => '全部顯示',
     'Month'                => '月',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => '移動',
     'MustBeGe'             => '需大於或等於',
     'MustBeLe'             => '需小於或等於',
@@ -509,6 +523,7 @@ $SLANG = array(
     'Pause'                => 'Pause',
     'Phone'                => 'Phone',
     'PhoneBW'              => 'Phone&nbsp;B/W',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel Diff',
     'Pixels'               => 'pixels',
     'Play'                 => 'Play',
@@ -564,6 +579,8 @@ $SLANG = array(
     'Secs'                 => 'Secs',
     'Sectionlength'        => '片段長度',
     'Select'               => '選取',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Select Monitors',
     'SelfIntersecting'     => 'Polygon edges must not intersect',
     'Set'                  => 'Set',
@@ -606,6 +623,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Submit',
     'System'               => 'System',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => '小圖檢視',
     'Tilt'                 => 'Tilt',
@@ -619,6 +637,7 @@ $SLANG = array(
     'TimestampLabelY'      => '時間標示 Y',
     'Today'                => 'Today',
     'Tools'                => 'Tools',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => '全部<br/>分數',
     'TrackDelay'           => 'Track Delay',
     'TrackMotion'          => 'Track Motion',
@@ -633,6 +652,8 @@ $SLANG = array(
     'Update'               => 'Update',                 // Added - 2009-02-08
     'UpdateAvailable'      => 'An update to ZoneMinder is available.',
     'UpdateNotNecessary'   => 'No update is necessary.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Use Filter',
     'UseFilterExprsPost'   => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -684,6 +705,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max Blobs',
     'ZoneMinMaxFiltArea'   => 'Min/Max Filtered Area',
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
     'Zones'                => '監視區',
     'Zoom'                 => 'Zoom',
