@@ -203,10 +203,14 @@ $SLANG = array(
     'CheckMethod'           => '报警检查方式',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'          => '选择筛选器',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'          => '选择预置',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                 => '关闭',
     'Colour'                => '彩色',
     'Command'               => '命令',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'                => '配置',
     'ConfiguredFor'         => '配置标的',
     'ConfirmDeleteEvents'   => '确认希望删除所选事件？',
@@ -226,6 +230,7 @@ $SLANG = array(
     'Controllable'          => '可控',
     'Cycle'                 => '循环',
     'CycleWatch'            => '循环监视',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                   => '日',
     'Debug'                 => '调试',
     'DefaultRate'           => '缺省速率',
@@ -247,6 +252,7 @@ $SLANG = array(
     'DisableAlarms'         => '关闭警报',
     'Disk'                  => '磁碟',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'                => '请捐款',
     'DonateAlready'         => '不，我已经捐赠过了',
     'DonateEnticement'      => '迄今，您已经运行ZoneMinder有一阵子了，希望它能够有助于增强您家或者办公区域的安全。尽管ZoneMinder是，并将保持免费和开源，该项目依然在研发和支持中投入了资金和精力。如果您愿意支持今后的开发和新功能，那么请考虑为该项目捐款。捐款不是必须的，任何数量的捐赠，我们都很感谢。<br/><br/>如果您愿意捐款，请选择下列选项，或者访问 http://www.zoneminder.com/donate.html 捐赠主页。<br/><br/>感谢您使用ZoneMinder，并且不要忘记访问访问ZoneMinder.com的论坛以获得支持或建议，这可以提升您的ZoneMinder的体验。',
@@ -284,6 +290,7 @@ $SLANG = array(
     'ExportFormatZip'       => 'Zip',
     'ExportFrames'          => '导出帧详情',
     'ExportImageFiles'      => '导出影像文件',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'       => '导出其他文件 (如果存在)',
     'ExportOptions'         => '导出选项',
     'ExportSucceeded'       => '导出成功',
@@ -359,16 +366,21 @@ $SLANG = array(
     'Language'              => '语言',
     'Last'                  => '最后',
     'Layout'                => '布局',
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'      => '个结果', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'       => '仅限于开始', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'        => '管理监视器',
     'List'                  => '列表',
     'Load'                  => '加载',
     'Local'                 => '本地',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'            => '登录为',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'             => '登录',
     'Login'                 => '登入',
     'Logout'                => '登出',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                   => '低',
     'LowBW'                 => '低&nbsp;B/W',
     'Main'                  => '主要',
@@ -402,6 +414,7 @@ $SLANG = array(
     'MaximumFPS'            => '最大帧率 FPS',
     'Medium'                => '中等',
     'MediumBW'              => '中等&nbsp;B/W',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'     => '最小报警区域应该小于最大区域',
     'MinAlarmAreaUnset'     => '您必须指定最小报警像素数量',
     'MinBlobAreaLtMax'      => '最小blob区必须小数最大区域',
@@ -445,6 +458,7 @@ $SLANG = array(
     'Monitors'              => '监视器',
     'Montage'               => '镜头组接',
     'Month'                 => '月',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                  => '移动',
     'MustBeGe'              => '必须大于等于',
     'MustBeLe'              => '必须小于等于',
@@ -505,6 +519,7 @@ $SLANG = array(
     'Pause'                 => '暂停',
     'Phone'                 => '电话',
     'PhoneBW'               => '电话&nbsp;B/W',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'             => '像素差别',
     'Pixels'                => '像素',
     'Play'                  => '播放',
@@ -560,6 +575,8 @@ $SLANG = array(
     'Secs'                  => '秒',
     'Sectionlength'         => '段长度',
     'Select'                => '选择',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'        => '选择监视器',
     'SelfIntersecting'      => '多边形边线不得交叉',
     'Set'                   => '设置',
@@ -602,6 +619,7 @@ $SLANG = array(
     'StreamReplayBuffer'    => '流重放影像缓冲',
     'Submit'                => '发送',
     'System'                => '系统',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                  => 'Tele',
     'Thumbnail'             => '缩略图',
     'Tilt'                  => '倾斜',
@@ -615,6 +633,7 @@ $SLANG = array(
     'TimestampLabelY'       => '时间戳标签 Y',
     'Today'                 => '今天',
     'Tools'                 => '工具',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'          => '总<br/>分数',
     'TrackDelay'            => '轨迹延时',
     'TrackMotion'           => '轨迹运动',
@@ -629,6 +648,8 @@ $SLANG = array(
     'Update'                => '更新',
     'UpdateAvailable'       => '有新版本的ZoneMinder.',
     'UpdateNotNecessary'    => '无须更新',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'             => '使用筛选器',
     'UseFilterExprsPost'    => '&nbsp;筛选器&nbsp;表达式', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'     => '使用&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -680,6 +701,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'       => '最小/最大污渍区数 Blobs',
     'ZoneMinMaxFiltArea'    => '最小/最大过滤区域',
     'ZoneMinMaxPixelThres'  => '最小/最大像素阈值(0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'    => '忽略过载帪数',
     'Zones'                 => '区域',
     'Zoom'                  => '缩放',
