@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web UK English language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -203,10 +203,14 @@ $SLANG = array(
     'CheckMethod'          => 'Metoda znakovn alarmem',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Vybrat filtr',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Choose Preset',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Zavt',
     'Colour'               => 'Barva',
     'Command'              => 'Pkaz',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Nastaven',
     'ConfiguredFor'        => 'Nastaveno pro',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
@@ -226,6 +230,7 @@ $SLANG = array(
     'Controllable'         => 'diteln',
     'Cycle'                => 'Cyklus',
     'CycleWatch'           => 'Cyklick prohlen',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Den',
     'Debug'                => 'Debug',
     'DefaultRate'          => 'Default Rate',
@@ -247,6 +252,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Zakzat alarmy',
     'Disk'                 => 'Disk',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Prosm podpote',
     'DonateAlready'        => 'Ne, u jsem podpoil',
     'DonateEnticement'     => 'Ji njakou dobu pouvte software ZoneMinder k ochran svho majetku a pedpokldm, e jej shledvte uitenm. Pestoe je ZoneMinder, znovu pipomnm, zdarma a voln en software, stoj jeho vvoj a podpora njak penze. Pokud byste chtl/a podpoit budouc vvoj a nov monosti softwaru, prosm zvate darovn finann pomoci. Darovn je, samozejm, dobrovoln, ale zato velmi cenn mete pispt jakou stkou chcete.<br><br>Pokud mte zjem podpoit n tm, prosm, vyberte ne uvedenou monost, nebo navtivte http://www.zoneminder.com/donate.html.<br><br>Dkuji Vm e jste si vybral/a software ZoneMinder a nezapomete navtvit frum na ZoneMinder.com pro podporu a nvrhy jak udlat ZoneMinder jet lepm ne je dnes.',
@@ -284,6 +290,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'Zip',
     'ExportFrames'         => 'Exportovat detaily snmku',
     'ExportImageFiles'     => 'Exportovat obrazov soubory',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Exportovat ostatn soubory (jestli existuj)',
     'ExportOptions'        => 'Monosti exportu',
     'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
@@ -359,16 +366,21 @@ $SLANG = array(
     'Language'             => 'Jazyk',
     'Last'                 => 'Posledn',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'vsledk', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Zobrazit pouze prvnch', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Linked Monitors',
     'List'                 => 'Seznam',
     'Load'                 => 'Load',
     'Local'                => 'Lokln',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Pihlen jako',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Pihlauji',
     'Login'                => 'Pihlsit',
     'Logout'               => 'Odhlsit',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Pomal',
     'LowBW'                => 'Pomal&nbsp;B/W',
     'Main'                 => 'Hlavn',
@@ -402,6 +414,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Maximum FPS',
     'Medium'               => 'Stedn',
     'MediumBW'             => 'Stedn&nbsp;B/W',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
     'MinBlobAreaLtMax'     => 'Minimum znakovan oblasti by mlo bt men ne maximum',
@@ -445,6 +458,7 @@ $SLANG = array(
     'Monitors'             => 'Kamery',
     'Montage'              => 'Sestih',
     'Month'                => 'Msc',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Pohyb',
     'MustBeGe'             => 'mus bt vt nebo rovno ne',
     'MustBeLe'             => 'mus bt men nebo rovno ne',
@@ -505,6 +519,7 @@ $SLANG = array(
     'Pause'                => 'Pause',
     'Phone'                => 'Modem',
     'PhoneBW'              => 'Modem&nbsp;B/W',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel Diff',
     'Pixels'               => 'pixely',
     'Play'                 => 'Play',
@@ -560,6 +575,8 @@ $SLANG = array(
     'Secs'                 => 'Dlka(s)',
     'Sectionlength'        => 'Dlka sekce',
     'Select'               => 'Vybrat',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Select Monitors',
     'SelfIntersecting'     => 'Polygon edges must not intersect',
     'Set'                  => 'Nastavit',
@@ -602,6 +619,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Potvrdit',
     'System'               => 'System',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Piblit',
     'Thumbnail'            => 'Miniatura',
     'Tilt'                 => 'Nklon',
@@ -615,6 +633,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'asov raztko Y',
     'Today'                => 'Dnes',
     'Tools'                => 'Nstroje',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Celkov<br/>skre',
     'TrackDelay'           => 'Prodleva drhy',
     'TrackMotion'          => 'Pohyb po drze',
@@ -629,6 +648,8 @@ $SLANG = array(
     'Update'               => 'Update',
     'UpdateAvailable'      => 'Je dostupn nov update ZoneMinder.',
     'UpdateNotNecessary'   => 'Update nen poteba.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Pout filtr',
     'UseFilterExprsPost'   => '&nbsp;vraz', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Pout&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -680,6 +701,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max Blobs',
     'ZoneMinMaxFiltArea'   => 'Min/Max Filtered Area',
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
     'Zones'                => 'Zny',
     'Zoom'                 => 'Zoom',
