@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web German language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web German language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -203,10 +203,14 @@ $SLANG = array(
     'CheckMethod'          => 'Alarm-Pr&uuml;fmethode',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Filterauswahl',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Voreinstellung ausw&auml;hlen',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Schlie&szlig;en',
     'Colour'               => 'Farbe',
     'Command'              => 'Kommando',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Konfig.',
     'ConfiguredFor'        => 'Konfiguriert f&uuml;r',
     'ConfirmDeleteEvents'  => 'Sind Sie sicher, dass Sie die ausgew&auml;hlten Ereignisse l&ouml;schen wollen?',
@@ -226,6 +230,7 @@ $SLANG = array(
     'Controllable'         => 'Kontrollierbar',
     'Cycle'                => 'Zyklus',
     'CycleWatch'           => 'Zeitzyklus',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Tag',
     'Debug'                => 'Debug',
     'DefaultRate'          => 'Standardrate',
@@ -247,6 +252,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Alarme abschalten',
     'Disk'                 => 'Disk',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Bitte spenden Sie.',
     'DonateAlready'        => 'Nein, ich habe schon gespendet',
     'DonateEnticement'     => 'Sie benutzen ZoneMinder nun schon eine Weile und es ist hoffentlich eine n&uuml;tzliche Applikation zur Verbesserung Ihrer Heim- oder Arbeitssicherheit. Obwohl ZoneMinder eine freie Open-Source-Software ist und bleiben wird, entstehen Kosten bei der Entwicklung und dem Support.<br><br>Falls Sie ZoneMinder fr Weiterentwicklung in der Zukunft unterst&uuml;tzen m&ouml;chten, denken Sie bitte ber eine Spende f&uuml;r das Projekt unter der Webadresse http://www.zoneminder.com/donate.html oder &uuml;ber nachfolgend stehende Option nach. Spenden sind, wie der Name schon sagt, immer freiwillig. Dem Projekt helfen kleine genauso wie gr&ouml;&szlig;ere Spenden sehr weiter und ein herzlicher Dank ist jedem Spender sicher.<br><br>Vielen Dank daf&uuml;r, dass sie ZoneMinder benutzen. Vergessen Sie nicht die Foren unter ZoneMinder.com, um Support zu erhalten und Ihre Erfahrung mit ZoneMinder zu verbessern!',
@@ -284,6 +290,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'ZIP (Komprimiert)',
     'ExportFrames'         => 'Exportiere Bilddetails',
     'ExportImageFiles'     => 'Exportiere Bilddateien',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Exportiere andere Dateien (falls vorhanden)',
     'ExportOptions'        => 'Exportierungsoptionen',
     'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
@@ -359,16 +366,21 @@ $SLANG = array(
     'Language'             => 'Sprache',
     'Last'                 => 'Letztes',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'Ergebnisse;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Begrenze nur auf die ersten', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Verbundene Monitore',
     'List'                 => 'Liste',
     'Load'                 => 'Last',
     'Local'                => 'Lokal',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Angemeldet als',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Anmelden',
     'Login'                => 'Anmeldung',
     'Logout'               => 'Abmelden',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'niedrige',
     'LowBW'                => 'Niedrige&nbsp;B/W',
     'Main'                 => 'Haupt',
@@ -402,6 +414,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Maximale FPS',
     'Medium'               => 'mittlere',
     'MediumBW'             => 'Mittlere&nbsp;B/W',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Der minimale Alarmbereich sollte kleiner sein als der maximale',
     'MinAlarmAreaUnset'    => 'Sie m&uuml;ssen einen Minimumwert an Alarmfl&auml;chenpixeln angeben',
     'MinBlobAreaLtMax'     => 'Die minimale Blob-Fl&auml;che muss kleiner sein als die maximale',
@@ -445,6 +458,7 @@ $SLANG = array(
     'Monitors'             => 'Monitore',
     'Montage'              => 'Montage',
     'Month'                => 'Monat',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Bewegung',
     'MustBeGe'             => 'muss groesser oder gleich sein wie',
     'MustBeLe'             => 'muss kleiner oder gleich sein wie',
@@ -505,6 +519,7 @@ $SLANG = array(
     'Pause'                => 'Pause',
     'Phone'                => 'Telefon',
     'PhoneBW'              => 'Tel.&nbsp;B/W',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel-Differenz',
     'Pixels'               => 'Pixel',
     'Play'                 => 'Abspielen',
@@ -560,6 +575,8 @@ $SLANG = array(
     'Secs'                 => 'Sekunden',
     'Sectionlength'        => 'Sektionsl&auml;nge',
     'Select'               => 'Auswahl',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'W&auml;hle Monitore',
     'SelfIntersecting'     => 'Die Polygonr&auml;nder d&uuml;rfen sich nicht &uuml;berschneiden.',
     'Set'                  => 'Setze',
@@ -602,6 +619,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Stream-Wiedergabe-Bildpuffer',
     'Submit'               => 'Absenden',
     'System'               => 'System',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Miniatur',
     'Tilt'                 => 'Neigung',
@@ -615,6 +633,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'Zeitstempel-Y',
     'Today'                => 'Heute',
     'Tools'                => 'Werkzeuge',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Totale<br/>Punktzahl',
     'TrackDelay'           => 'Nachf&uuml;hrungsverz&ouml;gerung',
     'TrackMotion'          => 'Bewegungs-Nachf&uuml;hrung',
@@ -629,6 +648,8 @@ $SLANG = array(
     'Update'               => 'Aktualisieren',
     'UpdateAvailable'      => 'Eine Aktualisierung f&uuml;r ZoneMinder ist verf&uuml;gbar.',
     'UpdateNotNecessary'   => 'Es ist keine Aktualisierung verf&uuml;gbar.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Benutze Filter',
     'UseFilterExprsPost'   => '&nbsp;Filter&nbsp;Ausdr&uuml;cke', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Benutze&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -680,6 +701,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min./max. Blobs',
     'ZoneMinMaxFiltArea'   => 'Min./max. Filterfl&auml;che',
     'ZoneMinMaxPixelThres' => 'Min./max. Pixelschwellwert',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Bildauslassrate bei System&uuml;berlastung',
     'Zones'                => 'Zonen',
     'Zoom'                 => 'Zoom',
