@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Danish language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web Danish language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -204,10 +204,14 @@ $SLANG = array(
     'CheckMethod'          => 'Alarm Check Methode',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Vlg Filter',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Choose Preset',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Luk',
     'Colour'               => 'Farve',
     'Command'              => 'Kommando',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'konfig',
     'ConfiguredFor'        => 'Konfigureret for',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
@@ -227,6 +231,7 @@ $SLANG = array(
     'Controllable'         => 'Controllable',
     'Cycle'                => 'Cycle',
     'CycleWatch'           => 'Cycle Watch',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Dag',
     'Debug'                => 'Debug',
     'DefaultRate'          => 'Default Rate',
@@ -248,6 +253,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Disable Alarms',
     'Disk'                 => 'Disk',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
     'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -285,6 +291,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'Zip',
     'ExportFrames'         => 'Export Frame Details',
     'ExportImageFiles'     => 'Export Image Files',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Export Other Files (if present)',
     'ExportOptions'        => 'Export Options',
     'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
@@ -360,16 +367,21 @@ $SLANG = array(
     'Language'             => 'Sprog',
     'Last'                 => 'Sidste',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'results only;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Limit to first', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Linked Monitors',
     'List'                 => 'List',
     'Load'                 => 'Load',
     'Local'                => 'Lokal',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Logget Ind Som',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Logger Ind',
     'Login'                => 'Logind',
     'Logout'               => 'Logud',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Lav',
     'LowBW'                => 'Lav&nbsp;B/B',
     'Main'                 => 'Main',
@@ -403,6 +415,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Maximale FPS',
     'Medium'               => 'Medium',
     'MediumBW'             => 'Medium&nbsp;B/B',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
     'MinBlobAreaLtMax'     => 'Minimum blob omrde br vre mindre end maximum',
@@ -446,6 +459,7 @@ $SLANG = array(
     'Monitors'             => 'Monitore',
     'Montage'              => 'Montage',
     'Month'                => 'Mned',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Flyt',
     'MustBeGe'             => 'skal vre stre end eller ligmed',
     'MustBeLe'             => 'Skal vre mindre end eller ligmed',
@@ -506,6 +520,7 @@ $SLANG = array(
     'Pause'                => 'Pause',
     'Phone'                => 'Telefon',
     'PhoneBW'              => 'Telefon&nbsp;B/B',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel Diff',
     'Pixels'               => 'pixels',
     'Play'                 => 'Play',
@@ -561,6 +576,8 @@ $SLANG = array(
     'Secs'                 => 'Sekunder',
     'Sectionlength'        => 'Sektion lngde',
     'Select'               => 'Vlg',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Select Monitors',
     'SelfIntersecting'     => 'Polygon edges must not intersect',
     'Set'                  => 'St',
@@ -603,6 +620,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Submit',
     'System'               => 'System',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Thumbnail',
     'Tilt'                 => 'Tilt',
@@ -616,6 +634,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'Tidsstempel Mrkning Y',
     'Today'                => 'Idag',
     'Tools'                => 'Tools',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Total<br/>Skore',
     'TrackDelay'           => 'Track Delay',
     'TrackMotion'          => 'Track Motion',
@@ -630,6 +649,8 @@ $SLANG = array(
     'Update'               => 'Update',
     'UpdateAvailable'      => 'En updatering til ZoneMinder er tilstede.',
     'UpdateNotNecessary'   => 'Ingen updatering er ndvendig.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Brug Filter',
     'UseFilterExprsPost'   => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Brug&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -681,6 +702,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max Blobs',
     'ZoneMinMaxFiltArea'   => 'Min/Max Filtered Area',
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
     'Zones'                => 'Zoner',
     'Zoom'                 => 'Zoom',
