@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web UK English language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -71,6 +71,15 @@
 
 // Simple String Replacements
 $SLANG = array(
+    'SystemLog'             => 'System Log',
+    'DateTime'              => 'Date/Time',
+    'Component'             => 'Component',
+    'Pid'                   => 'PID',
+    'Level'                 => 'Level',
+    'Message'               => 'Message',
+    'Line'                  => 'Line',
+    'More'                  => 'More',
+    'Clear'                 => 'Clear',
     '24BitColour'           => '24 bit colour',
     '8BitGrey'              => '8 bit greyscale',
     'Action'                => 'Action',
@@ -119,6 +128,7 @@ $SLANG = array(
     'AttrWeekday'           => 'Weekday',
     'Auto'                  => 'Auto',
     'AutoStopTimeout'       => 'Auto Stop Timeout',
+    'Available'             => 'Available',
     'AvgBrScore'            => 'Avg.<br/>Score',
     'Available'             => 'Available',
     'Background'            => 'Background',
@@ -200,10 +210,11 @@ $SLANG = array(
     'CapturePalette'        => 'Capture Palette',
     'CaptureWidth'          => 'Capture Width',
     'Cause'                 => 'Cause',
-    'Layout'                => 'Layout',
     'CheckMethod'           => 'Alarm Check Method',
     'ChooseDetectedCamera'  => 'Choose Detected Camera',
     'ChooseFilter'          => 'Choose Filter',
+    'ChooseLogFormat'       => 'Choose a log format',
+    'ChooseLogSelection'    => 'Choose a log selection',
     'ChoosePreset'          => 'Choose Preset',
     'Close'                 => 'Close',
     'Colour'                => 'Colour',
@@ -248,6 +259,7 @@ $SLANG = array(
     'DisableAlarms'         => 'Disable Alarms',
     'Disk'                  => 'Disk',
     'Display'               => 'Display',
+    'Displaying'            => 'Displaying',
     'DonateAlready'         => 'No, I\'ve already donated',
     'DonateEnticement'      => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br/><br/>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br/><br/>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
     'Donate'                => 'Please Donate',
@@ -285,6 +297,7 @@ $SLANG = array(
     'ExportFormatZip'       => 'Zip',
     'ExportFrames'          => 'Export Frame Details',
     'ExportImageFiles'      => 'Export Image Files',
+    'ExportLog'             => 'Export Log',
     'Exporting'             => 'Exporting',
     'ExportMiscFiles'       => 'Export Other Files (if present)',
     'ExportOptions'         => 'Export Options',
@@ -359,12 +372,16 @@ $SLANG = array(
     'Label'                 => 'Label',
     'Language'              => 'Language',
     'Last'                  => 'Last',
+    'Layout'                => 'Layout',
     'LimitResultsPost'      => 'results only', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'       => 'Limit to first', // This is used at the beginning of the phrase 'Limit to first N results only'
     'LinkedMonitors'        => 'Linked Monitors',
     'List'                  => 'List',
     'Load'                  => 'Load',
     'Local'                 => 'Local',
+    'Log'                   => 'Log',
+    'Logs'                  => 'Logs',
+    'Logging'               => 'Logging',
     'LoggedInAs'            => 'Logged in as',
     'LoggingIn'             => 'Logging In',
     'Login'                 => 'Login',
@@ -561,6 +578,8 @@ $SLANG = array(
     'Sectionlength'         => 'Section length',
     'SelectMonitors'        => 'Select Monitors',
     'Select'                => 'Select',
+    'SelectFormat'          => 'Select Format',
+    'SelectLog'             => 'Select Log',
     'SelfIntersecting'      => 'Polygon edges must not intersect',
     'SetNewBandwidth'       => 'Set New Bandwidth',
     'SetPreset'             => 'Set Preset',
@@ -615,6 +634,7 @@ $SLANG = array(
     'Time'                  => 'Time',
     'Today'                 => 'Today',
     'Tools'                 => 'Tools',
+    'Total'                 => 'Total',
     'TotalBrScore'          => 'Total<br/>Score',
     'TrackDelay'            => 'Track Delay',
     'TrackMotion'           => 'Track Motion',
@@ -629,6 +649,8 @@ $SLANG = array(
     'UpdateAvailable'       => 'An update to ZoneMinder is available.',
     'UpdateNotNecessary'    => 'No update is necessary.',
     'Update'                => 'Update',
+    'Upload'                => 'Upload',
+    'Updated'               => 'Updated',
     'UseFilterExprsPost'    => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'     => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
     'UseFilter'             => 'Use Filter',
@@ -674,6 +696,7 @@ $SLANG = array(
     'ZoneAlarmColour'       => 'Alarm Colour (Red/Green/Blue)',
     'ZoneArea'              => 'Zone Area',
     'ZoneFilterSize'        => 'Filter Width/Height (pixels)',
+    'ZoneMinderLog'         => 'ZoneMinder Log',
     'ZoneMinMaxAlarmArea'   => 'Min/Max Alarmed Area',
     'ZoneMinMaxBlobArea'    => 'Min/Max Blob Area',
     'ZoneMinMaxBlobs'       => 'Min/Max Blobs',
