@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Argentinian Spanish language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web Argentinian Spanish language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -154,10 +154,14 @@ $SLANG = array(
     'CheckMethod'          => 'Alarm Check Method',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Elegir Filtro',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Choose Preset',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Cerrar',
     'Colour'               => 'Color',
     'Command'              => 'Command',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'           => 'Config.',
     'ConfiguredFor'        => 'Configurado Para',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
@@ -177,6 +181,7 @@ $SLANG = array(
     'Controllable'         => 'Controllable',
     'Cycle'                => 'Cycle',
     'CycleWatch'           => 'Cycle Watch',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Da',
     'Debug'                => 'Debug',
     'DefaultRate'          => 'Default Rate',
@@ -198,6 +203,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Disable Alarms',
     'Disk'                 => 'Disco',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
     'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -235,6 +241,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'Zip',
     'ExportFrames'         => 'Export Frame Details',
     'ExportImageFiles'     => 'Export Image Files',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Export Other Files (if present)',
     'ExportOptions'        => 'Export Options',
     'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
@@ -310,16 +317,21 @@ $SLANG = array(
     'Language'             => 'Lenguaje',
     'Last'                 => 'Ultimo',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'Resultados;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Solo los primeros', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Linked Monitors',
     'List'                 => 'List',
     'Load'                 => 'Carga',
     'Local'                => 'Local',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Registrado Como',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Ingresando',
     'Login'                => 'Ingresar',
     'Logout'               => 'Salir',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Baja',
     'LowBW'                => 'Baja&nbsp;B/W',
     'Main'                 => 'Main',
@@ -353,6 +365,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Maximos FPS',
     'Medium'               => 'Media',
     'MediumBW'             => 'Media&nbsp;B/W',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
     'MinBlobAreaLtMax'     => 'Minimum blob area should be less than maximum',
@@ -396,6 +409,7 @@ $SLANG = array(
     'Monitors'             => 'Monitores',
     'Montage'              => 'Cmara Mltiple',
     'Month'                => 'Mes',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Move',
     'MustBeGe'             => 'Debe ser mayor o igual que',
     'MustBeLe'             => 'Debe ser menor o igual que',
@@ -456,6 +470,7 @@ $SLANG = array(
     'Pause'                => 'Pause',
     'Phone'                => 'Phone',
     'PhoneBW'              => 'Tel.&nbsp;B/N',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel Diff',             // Added - 2009-02-08
     'Pixels'               => 'pixels',
     'Play'                 => 'Play',
@@ -511,6 +526,8 @@ $SLANG = array(
     'Secs'                 => 'Seg',
     'Sectionlength'        => 'Longitud Seccin',
     'Select'               => 'Select',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Select Monitors',
     'SelfIntersecting'     => 'Polygon edges must not intersect',
     'Set'                  => 'Set',
@@ -553,6 +570,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Submit',
     'System'               => 'Sistema',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Thumbnail',
     'Tilt'                 => 'Tilt',
@@ -566,6 +584,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'Eje Y Etiqueta Hora',
     'Today'                => 'Today',
     'Tools'                => 'Herra.',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Total<br/>puntuacin',
     'TrackDelay'           => 'Track Delay',
     'TrackMotion'          => 'Track Motion',
@@ -580,6 +599,8 @@ $SLANG = array(
     'Update'               => 'Update',
     'UpdateAvailable'      => 'Una Actualizacin a ZoneMinder esta disponible',
     'UpdateNotNecessary'   => 'No se requiere Actualizacin',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Usar Filtro',
     'UseFilterExprsPost'   => '&nbsp;filtrar&nbsp;sentencias', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Utilizar&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -631,6 +652,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max Blobs',
     'ZoneMinMaxFiltArea'   => 'Min/Max Filtered Area',
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
     'Zones'                => 'Zonas',
     'Zoom'                 => 'Zoom',
