@@ -199,10 +199,14 @@ $SLANG = array(
     'CheckMethod'           => 'Alarm Check Method',
     'ChooseDetectedCamera'  => 'Vali tuvastatud kaamera',
     'ChooseFilter'          => 'Vali Filter',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'          => 'Choose Preset',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                 => 'Sule',
     'Colour'                => 'Colour',
     'Command'               => 'Command',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'                => 'Config',
     'ConfiguredFor'         => 'Seadistatud',
     'ConfirmDeleteEvents'   => 'Oled sa kindel kustamaks valitud sündmused?',
@@ -222,6 +226,7 @@ $SLANG = array(
     'Controllable'          => 'Controllable',
     'Cycle'                 => 'Cycle',
     'CycleWatch'            => 'Cycle Watch',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                   => 'Päevas',
     'Debug'                 => 'Debug',
     'DefaultRate'           => 'Default Rate',
@@ -243,6 +248,7 @@ $SLANG = array(
     'DisableAlarms'         => 'Keela alarmid',
     'Disk'                  => 'Disk',
     'Display'              => 'Display',                // Added - 2011-03-02
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'                => 'Please Donate',
     'DonateAlready'         => 'No, I\'ve already donated',
     'DonateEnticement'      => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br/><br/>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br/><br/>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -280,6 +286,7 @@ $SLANG = array(
     'ExportFormatZip'       => 'Zip',
     'ExportFrames'          => 'Export Frame Details',
     'ExportImageFiles'      => 'Export Image Files',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'       => 'Export Other Files (if present)',
     'ExportOptions'         => 'Export Options',
     'ExportSucceeded'       => 'Export Succeeded',
@@ -355,16 +362,21 @@ $SLANG = array(
     'Language'              => 'Keel',
     'Last'                  => 'Viimane',
     'Layout'                => 'Layout',
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'      => 'results only', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'       => 'Limit to first', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'        => 'Lingitud monitorid',
     'List'                  => 'List',
     'Load'                  => 'Koormus',
     'Local'                 => 'Local',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'            => 'Sisse logitud',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'             => 'Login sisse',
     'Login'                 => 'Login',
     'Logout'                => 'Logi välja',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                   => 'Madal',
     'LowBW'                 => 'Low&nbsp;B/W',
     'Main'                  => 'Main',
@@ -398,6 +410,7 @@ $SLANG = array(
     'MaximumFPS'            => 'Maksimaalne FPS',
     'Medium'                => 'Keskmine',
     'MediumBW'              => 'Medium&nbsp;B/W',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'     => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'     => 'You must specify the minimum alarm pixel count',
     'MinBlobAreaLtMax'      => 'Minimum blob area should be less than maximum',
@@ -441,6 +454,7 @@ $SLANG = array(
     'Monitors'              => 'Monitors',
     'Montage'               => 'Montage',
     'Month'                 => 'Kuus',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                  => 'Move',
     'MustBeGe'              => 'must be greater than or equal to',
     'MustBeLe'              => 'must be less than or equal to',
@@ -501,6 +515,7 @@ $SLANG = array(
     'Pause'                 => 'Pause',
     'Phone'                 => 'Phone',
     'PhoneBW'               => 'Phone&nbsp;B/W',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'             => 'Pixel Diff',
     'Pixels'                => 'pixels',
     'Play'                  => 'Play',
@@ -556,6 +571,8 @@ $SLANG = array(
     'Secs'                  => 'Secs',
     'Sectionlength'         => 'Section length',
     'Select'                => 'Select',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'        => 'Select Monitors',
     'SelfIntersecting'      => 'Polygon edges must not intersect',
     'Set'                   => 'Set',
@@ -598,6 +615,7 @@ $SLANG = array(
     'StreamReplayBuffer'    => 'Stream Replay Image Buffer',
     'Submit'                => 'Submit',
     'System'                => 'System',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                  => 'Tele',
     'Thumbnail'             => 'Thumbnail',
     'Tilt'                  => 'Tilt',
@@ -611,6 +629,7 @@ $SLANG = array(
     'TimestampLabelY'       => 'Timestamp Label Y',
     'Today'                 => 'Today',
     'Tools'                 => 'Tools',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'          => 'Total<br/>Score',
     'TrackDelay'            => 'Track Delay',
     'TrackMotion'           => 'Track Motion',
@@ -625,6 +644,8 @@ $SLANG = array(
     'Update'                => 'Update',
     'UpdateAvailable'       => 'An update to ZoneMinder is available.',
     'UpdateNotNecessary'    => 'No update is necessary.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'             => 'Use Filter',
     'UseFilterExprsPost'    => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'     => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -676,6 +697,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'       => 'Min/Max Blobs',
     'ZoneMinMaxFiltArea'    => 'Min/Max Filtered Area',
     'ZoneMinMaxPixelThres'  => 'Min/Max Pixel Threshold (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'    => 'Overload Frame Ignore Count',
     'Zones'                 => 'Tsoone',
     'Zoom'                  => 'Zoom',
