@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web HU Hungarian language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web HU Hungarian language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -212,10 +212,14 @@ $SLANG = array(
     'CheckMethod'          => 'A riaszts figyelsnek mdja',
     'ChooseDetectedCamera' => 'Vlasszon rzkelt kamert',
     'ChooseFilter'         => 'Vlassz szrt',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Vlassz profilt',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Bezr',
     'Colour'               => 'Szn',
     'Command'              => 'Parancs',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Bellts',
     'ConfiguredFor'        => 'Belltva',
     'ConfirmDeleteEvents'  => 'Biztos benne, hogy trli a kivlasztott esemnyeket?',
@@ -235,6 +239,7 @@ $SLANG = array(
     'Controllable'         => 'Vezrelhet',
     'Cycle'                => 'Krbekapcsols',
     'CycleWatch'           => 'Krbekapcsols',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Napon',
     'Debug'                => 'Nyomon<br>kvets',
     'DefaultRate'          => 'Alaprtelmezett sebessg',
@@ -256,6 +261,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Riaszts tiltsa',
     'Disk'                 => 'Trhely',
     'Display'               => 'Megjelens',
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Krem tmogasson',
     'DonateAlready'        => 'Nem, n mr tmogattam',
     'DonateEnticement'     => 'n mr j ideje hasznlja a ZoneMindert remlhetleg hasznos kiegsztsnek tartja hza vagy munkahelye biztostsban. Br ZoneMinder szabad, nylt forrskd, s az is marad; a fejlesztse pnzbe kerl. Ha tmogatni szeretn a jvbeni fejlesztseket s az j funkcikat krem tmogasson. A tmogats teljesen nkntes, de nagyon megbecslt s annyival tud tmogatni amennyivel kvn.<br><br>Ha tmogatni szertne krem vlasszon az albbi lehetsgekbl vagy ltogassa meg a http://www.zoneminder.com/donate.html oldalt.<br><br>Ksznm, hogy hasznlja a ZoneMinder-t s ne felejtse el megltogatni a frumokat a ZoneMinder.com oldalon tmogatsrt s tletekrt, hogy tudja mg jobban hasznlni a ZoneMinder-t.',
@@ -293,6 +299,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'ZIP',
     'ExportFrames'         => 'Kpek adatainak exportlsa',
     'ExportImageFiles'     => 'Kpek exportlsa',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Egyb fjlok exportlsa (ha vannak)',
     'ExportOptions'        => 'Exportls belltsai',
     'ExportSucceeded'      => 'Az exportls sikerlt',
@@ -368,16 +375,21 @@ $SLANG = array(
     'Language'             => 'Nyelv',
     'Last'                 => 'Utols',
     'Layout'               => 'Elrendezs',
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'tallatig korltoz', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Az els', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'sszefgg monitorok',
     'List'                 => 'Lista',
     'Load'                 => 'Terhels',
     'Local'                => 'Helyi',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Bejelentkezve mint',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Bejelentkezs folyamatban',
     'Login'                => 'Bejelentkezs',
     'Logout'               => 'Kilps',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Alacsony',
     'LowBW'                => 'Alacsony<br>svsz.',
     'Main'                 => 'F',
@@ -411,6 +423,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Maximum FPS',
     'Medium'               => 'Kzepes',
     'MediumBW'             => 'Kzepes<br>svsz.',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'A minimum riasztott terletnek kisebbnek kell lennie mint a maximumnak',
     'MinAlarmAreaUnset'    => 'Meg kell adnod a minimum riasztott kppontok szmt',
     'MinBlobAreaLtMax'     => 'A minimum blob terletnek kisebbnek kell lennie mint a maximumnak',
@@ -454,6 +467,7 @@ $SLANG = array(
     'Monitors'             => 'Monitorok',
     'Montage'              => 'Tbbkamers nzet',
     'Month'                => 'Hnapban',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Mozgs',
     'MustBeGe'             => 'nagyobbnak vagy egyenlnek kell lennie',
     'MustBeLe'             => 'kisebbnek vagy egyenlnek kell lennie',
@@ -514,6 +528,7 @@ $SLANG = array(
     'Pause'                => 'Sznet',
     'Phone'                => 'Telefonon betrcszva',
     'PhoneBW'              => 'Betrcsz<br>svsz.',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Kppont eltrs',
     'Pixels'               => 'kppont',
     'Play'                 => 'Lejtszs',
@@ -569,6 +584,8 @@ $SLANG = array(
     'Secs'                 => 'mp.',
     'Sectionlength'        => 'Rsz hossz',
     'Select'               => 'Kivlaszts',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Monitorok kivlasztsa',
     'SelfIntersecting'     => 'A sokszg szlei nem keresztezdhetnek',
     'Set'                  => 'Bellt',
@@ -611,6 +628,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Folyam visszajtsz kppuffer',
     'Submit'               => 'Elkld',
     'System'               => 'Rendszer',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tv',
     'Thumbnail'            => 'Elnzet',
     'Tilt'                 => 'Fel-le mozgs',
@@ -624,6 +642,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'Elhelyezs Y pozici',
     'Today'                => 'Ma',
     'Tools'                => 'Eszkzk',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'ssz.<br/>pontszm',
     'TrackDelay'           => 'Ksleltets kvetse',
     'TrackMotion'          => 'Mozgs kvetse',
@@ -638,6 +657,8 @@ $SLANG = array(
     'Update'               => 'Frissts',
     'UpdateAvailable'      => 'Elrhet ZoneMinder frissts.',
     'UpdateNotNecessary'   => 'Nem szksges a frissts.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Szrt hasznl',
     'UseFilterExprsPost'   => '&nbsp;szr&nbsp;kifejezs hasznlata', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => '&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -689,6 +710,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max Blobok',
     'ZoneMinMaxFiltArea'   => 'Min/Max szrt terlet',
     'ZoneMinMaxPixelThres' => 'Min/Max kppont eltrsi<br>kszb (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Tlterhels esetn<br>ennyi kpkocka hagyhat ki',
     'Zones'                => 'Znk',
     'Zoom'                 => 'Zoom',
