@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Italian language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web Italian language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -208,10 +208,14 @@ $SLANG = array(
     'CheckMethod'          => 'Metodo di Controllo Allarme',
     'ChooseDetectedCamera' => 'Scegli telecamera rilevata', // Added - 2009-03-31
     'ChooseFilter'         => 'Scegli Filtro',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Scegli Preset',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Chiudi',
     'Colour'               => 'Colori',
     'Command'              => 'Comando',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Configura',
     'ConfiguredFor'        => 'Configurato per',
     'ConfirmDeleteEvents'  => 'Sei sicuro di voler cancellare gli eventi selezionati',
@@ -231,6 +235,7 @@ $SLANG = array(
     'Controllable'         => 'Controllabile',
     'Cycle'                => 'Cicla',
     'CycleWatch'           => 'Vista Ciclica',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Giorno',
     'Debug'                => 'Debug',
     'DefaultRate'          => 'Default Rate',
@@ -252,6 +257,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Disabil Allarme',
     'Disk'                 => 'Utilizzo Disco',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Donate,per favore',
     'DonateAlready'        => 'No, ho gia donato...    ',
     'DonateEnticement'     => 'Stai usando ZoneMinder da un po\' di tempo e spero che tu lo stia trovando utile per la sicurezza di casa tua o del tuo posto di lavoro..Anche se ZoneMinder e\' distribuito liberamente come software libero,costa soldi sia svilupparlo che supportarlo. Se preferisci che questo software continui ad avere supporto e sviluppo in futuro allora considera l\idea di fare una piccola donazione. Donare e\' ovviamente opzionale, ma apprezzato e puoi donare quanto vuoi,quel poco o tanto che tu desideri.<br><br>Se hai voglia per cortesia seleziona l\'opzione sotto o punta il tuo browser a http://www.zoneminder.com/donate.html .<br><br>Grazie per usare ZoneMinder e non dimenticare di visitare il forum in ZoneMinder.com se cerchi supporto o hai suggerimenti riguardo a come rendere migliore Zoneminder.',
@@ -289,6 +295,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'Zip',
     'ExportFrames'         => 'Dettagli frame espo.',
     'ExportImageFiles'     => 'Esporta le immagini',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Esporto Altri file (se presenti)',
     'ExportOptions'        => 'Opzioni Esportazione',
     'ExportSucceeded'      => 'Export completata con successo',       // Added - 2009-02-08
@@ -364,16 +371,21 @@ $SLANG = array(
     'Language'             => 'Linguaggio',
     'Last'                 => 'Ultimo',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'risultati;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Limita ai primi', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Monitor Collegati',
     'List'                 => 'Lista',
     'Load'                 => 'Carico Sistema',
     'Local'                => 'Locale',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Collegato come:',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Mi Sto Collegando',
     'Login'                => 'Login',
     'Logout'               => 'Logout',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Bassa',
     'LowBW'                => 'Banda&nbsp;Bassa',
     'Main'                 => 'Principale',
@@ -407,6 +419,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Massimi FPS',
     'Medium'               => 'Media',
     'MediumBW'             => 'Banda&nbsp;Media',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'L\'area minima dell\'allarme deve essere minore di quella massima',
     'MinAlarmAreaUnset'    => 'Devi specificare il numero minimo di pixel per l\'allarme',
     'MinBlobAreaLtMax'     => 'L\'area di blob minima deve essere minore dell\'area di blob massima',
@@ -450,6 +463,7 @@ $SLANG = array(
     'Monitors'             => 'Monitors',
     'Montage'              => 'Montaggio',
     'Month'                => 'Mese',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Sposta',
     'MustBeGe'             => 'deve essere superiore a',
     'MustBeLe'             => 'deve essere inferiore o pari a',
@@ -510,6 +524,7 @@ $SLANG = array(
     'Pause'                => 'Pause',
     'Phone'                => 'Telefono',
     'PhoneBW'              => 'Banda&nbsp;Tel',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel Diff',
     'Pixels'               => 'pixels',
     'Play'                 => 'Play',
@@ -565,6 +580,8 @@ $SLANG = array(
     'Secs'                 => 'Secs',
     'Sectionlength'        => 'Lunghezza Sezione',
     'Select'               => 'Seleziona',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Monitor Selezionati',
     'SelfIntersecting'     => 'I vertici del poligono non devono intersecarsi',
     'Set'                  => 'Imposta',
@@ -607,6 +624,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Accetta',
     'System'               => 'Sistema',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Anteprima',
     'Tilt'                 => 'Tilt',
@@ -620,6 +638,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'coordinata Y etichetta',
     'Today'                => 'Oggi ',
     'Tools'                => 'Strumenti',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Punteggio<br/>Totale',
     'TrackDelay'           => 'Track Delay',
     'TrackMotion'          => 'Track Motion',
@@ -634,6 +653,8 @@ $SLANG = array(
     'Update'               => 'Aggiorna',
     'UpdateAvailable'      => 'Un aggiornamento di ZoneMinder &egrave; disponibilie.',
     'UpdateNotNecessary'   => 'Nessun aggiornamento necessario.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Usa Filtro',
     'UseFilterExprsPost'   => '&nbsp;espressioni&nbsp;filtri', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Usa&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -685,6 +706,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max Blobs',
     'ZoneMinMaxFiltArea'   => 'Min/Max Area Filtrata',
     'ZoneMinMaxPixelThres' => 'Min/Max Soglia Pixel (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
     'Zones'                => 'Zone',
     'Zoom'                 => 'Zoom',
