@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Polish language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web Polish language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -203,10 +203,14 @@ $SLANG = array(
     'CheckMethod'          => 'Metoda sprawdzenia alarmu',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Wybierz filtr',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Choose Preset',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Zamknij',
     'Colour'               => 'Nasycenie',
     'Command'              => 'Command',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Konfiguracja',
     'ConfiguredFor'        => 'Ustawiona',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
@@ -226,6 +230,7 @@ $SLANG = array(
     'Controllable'         => 'Controllable',
     'Cycle'                => 'Cycle',
     'CycleWatch'           => 'Cykl podgldu',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Dzie',
     'Debug'                => 'Debug',
     'DefaultRate'          => 'Default Rate',
@@ -247,6 +252,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Disable Alarms',
     'Disk'                 => 'Dysk',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
     'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -284,6 +290,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'Zip',
     'ExportFrames'         => 'Export Frame Details',
     'ExportImageFiles'     => 'Export Image Files',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Export Other Files (if present)',
     'ExportOptions'        => 'Export Options',
     'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
@@ -359,16 +366,21 @@ $SLANG = array(
     'Language'             => 'Jzyk',
     'Last'                 => 'Ostatni',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'wynikw;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Ogranicz do pocztkowych', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Linked Monitors',
     'List'                 => 'List',
     'Load'                 => 'Obc.',
     'Local'                => 'Lokalny',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Zalogowany jako',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Logowanie',
     'Login'                => 'Login',
     'Logout'               => 'Wyloguj',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'niska',
     'LowBW'                => 'Nis.&nbsp;prz.',
     'Main'                 => 'Main',
@@ -402,6 +414,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Maks. FPS',
     'Medium'               => 'rednia',
     'MediumBW'             => 'red.&nbsp;prz.',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
     'MinBlobAreaLtMax'     => 'Minimalny obszar plamki powinien by mniejszy od maksymalnego obszaru plamki',
@@ -445,6 +458,7 @@ $SLANG = array(
     'Monitors'             => 'Monitory',
     'Montage'              => 'Monta',
     'Month'                => 'Miesic',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Move',
     'MustBeGe'             => 'musi by wiksze lub rwne od',
     'MustBeLe'             => 'musi by mniejsze lub rwne od',
@@ -505,6 +519,7 @@ $SLANG = array(
     'Pause'                => 'Pause',
     'Phone'                => 'Phone',
     'PhoneBW'              => 'Tel.&nbsp;prz.',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel Diff',
     'Pixels'               => 'pikseli',
     'Play'                 => 'Play',
@@ -560,6 +575,8 @@ $SLANG = array(
     'Secs'                 => 'Sekund',
     'Sectionlength'        => 'Dugo sekcji',
     'Select'               => 'Select',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Select Monitors',
     'SelfIntersecting'     => 'Polygon edges must not intersect',
     'Set'                  => 'Set',
@@ -602,6 +619,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Submit',
     'System'               => 'System',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Thumbnail',
     'Tilt'                 => 'Tilt',
@@ -615,6 +633,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'Wsp. Y etykiety czasu',
     'Today'                => 'Today',
     'Tools'                => 'Narzdzia',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Cakowity<br/>wynik',
     'TrackDelay'           => 'Track Delay',
     'TrackMotion'          => 'Track Motion',
@@ -629,6 +648,8 @@ $SLANG = array(
     'Update'               => 'Update',
     'UpdateAvailable'      => 'Jest dostpne uaktualnienie ZoneMinder ',
     'UpdateNotNecessary'   => 'Nie jest wymagane uaktualnienie',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Uyj filtru',
     'UseFilterExprsPost'   => '&nbsp;wyraenie&nbsp;filtru', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Uyj&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -680,6 +701,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max Blobs',
     'ZoneMinMaxFiltArea'   => 'Min/Max Filtered Area',
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
     'Zones'                => 'Strefy',
     'Zoom'                 => 'Zoom',
