@@ -143,10 +143,14 @@ $SLANG = array(
     'CheckMethod'          => 'Metodo marcar por alarme',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Escolher Filtro',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Choose Preset',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Fechar',
     'Colour'               => 'Cor',
     'Command'              => 'Command',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Config',
     'ConfiguredFor'        => 'Configurado para',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
@@ -166,6 +170,7 @@ $SLANG = array(
     'Controllable'         => 'Controllable',
     'Cycle'                => 'Cycle',
     'CycleWatch'           => 'Ciclo Monitor',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Dia',
     'Debug'                => 'Debug',
     'DefaultRate'          => 'Default Rate',
@@ -187,6 +192,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Disable Alarms',
     'Disk'                 => 'Disco',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
     'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -224,6 +230,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'Zip',
     'ExportFrames'         => 'Export Frame Details',
     'ExportImageFiles'     => 'Export Image Files',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Export Other Files (if present)',
     'ExportOptions'        => 'Export Options',
     'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
@@ -299,16 +306,21 @@ $SLANG = array(
     'Language'             => 'Linguagem',
     'Last'                 => 'ltimo',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'resultados somente;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Limitar aos primeiros', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Linked Monitors',
     'List'                 => 'List',
     'Load'                 => 'Carga',
     'Local'                => 'Local',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Conectado como',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Conectando',
     'Login'                => 'Conectar',
     'Logout'               => 'Sair',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Baixa',
     'LowBW'                => 'Baixa&nbsp;L/B',
     'Main'                 => 'Main',
@@ -342,6 +354,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Maximo FPS',
     'Medium'               => 'Media',
     'MediumBW'             => 'Media&nbsp;L/B',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
     'MinBlobAreaLtMax'     => 'A area minima de blob deve ser menor do que a area mxima de blob',
@@ -385,6 +398,7 @@ $SLANG = array(
     'Monitors'             => 'Monitores',
     'Montage'              => 'Montagem',
     'Month'                => 'Ms',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Move',
     'MustBeGe'             => 'deve ser maior ou igual a',
     'MustBeLe'             => 'deve ser menor ou igual a',
@@ -445,6 +459,7 @@ $SLANG = array(
     'Pause'                => 'Pause',
     'Phone'                => 'Phone',
     'PhoneBW'              => 'Discada&nbsp;L/B',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel Diff',
     'Pixels'               => 'pixels',
     'Play'                 => 'Play',
@@ -500,6 +515,8 @@ $SLANG = array(
     'Secs'                 => 'Segs',
     'Sectionlength'        => 'Tamanho de evento Fixo',
     'Select'               => 'Select',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Select Monitors',
     'SelfIntersecting'     => 'Polygon edges must not intersect',
     'Set'                  => 'Set',
@@ -542,6 +559,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Submit',
     'System'               => 'Sistema',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Thumbnail',
     'Tilt'                 => 'Tilt',
@@ -555,6 +573,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'posio de  etiqueta Y',
     'Today'                => 'Today',
     'Tools'                => 'Ferramentas',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Score<br/>Total',
     'TrackDelay'           => 'Track Delay',
     'TrackMotion'          => 'Track Motion',
@@ -569,6 +588,8 @@ $SLANG = array(
     'Update'               => 'Update',
     'UpdateAvailable'      => 'Um update ao zoneminder est disponvel.',
     'UpdateNotNecessary'   => 'No  necessrio update.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Use Filtro',
     'UseFilterExprsPost'   => '&nbsp;expresses&nbsp;de&nbsp;filtragem', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -620,6 +641,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max Blobs',
     'ZoneMinMaxFiltArea'   => 'Min/Max Filtered Area',
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
     'Zones'                => 'Zonas',
     'Zoom'                 => 'Zoom',
