@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Swedish language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
+// ZoneMinder web Swedish language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -204,10 +204,14 @@ $SLANG = array(
     'CheckMethod'          => 'Larmkontrollmetod',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Vlj filter',
+    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Vlj standard',
+    'Clear'                => 'Clear',                  // Added - 2011-06-16
     'Close'                => 'Stng',
     'Colour'               => 'Frg',
     'Command'              => 'Kommando',
+    'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Konfigurera',
     'ConfiguredFor'        => 'Konfigurerad fr',
     'ConfirmDeleteEvents'  => 'r du sker p att du vill ta bort dom valda hndelserna?',
@@ -227,6 +231,7 @@ $SLANG = array(
     'Controllable'         => 'Kontrollerbar',
     'Cycle'                => 'Period',
     'CycleWatch'           => 'Cycle Watch',
+    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
     'Day'                  => 'Dag',
     'Debug'                => 'Avlusa',
     'DefaultRate'          => 'Standardhastighet',
@@ -248,6 +253,7 @@ $SLANG = array(
     'DisableAlarms'        => 'Avaktivera larm',
     'Disk'                 => 'Disk',
     'Display'              => 'Display',                // Added - 2011-01-30
+    'Displaying'           => 'Displaying',             // Added - 2011-06-16
     'Donate'               => 'Var vnlig och donera',
     'DonateAlready'        => 'Nej, Jag har redan donerat',
     'DonateEnticement'     => 'Du har krt ZoneMinder ett tag nu och frhoppningsvis har du sett att det fungerar bra hemma eller p ditt fretag. ven om ZoneMinder r, och kommer att vara, fri programvara och ppen kallkod, s kostar det pengar att utveckla och underhlla. Om du vill hjlpa till med framtida utveckling och nya funktioner s var vanlig och bidrag med en slant. Bidragen r naturligtvis en option men mycket uppskattade och du kan bidra med precis hur mycket du vill.<br><br>Om du vill ge ett bidrag vljer du nedan eller surfar till http://www.zoneminder.com/donate.html.<br><br>Tack fr att du anvnder ZoneMinder, glm inte att beska forumen p ZoneMinder.com fr support och frslag om hur du fr din ZoneMinder att fungera lite bttre.',
@@ -285,6 +291,7 @@ $SLANG = array(
     'ExportFormatZip'      => 'Zip',
     'ExportFrames'         => 'Exportera ramdetaljer',
     'ExportImageFiles'     => 'Exportera bildfiler',
+    'ExportLog'            => 'Export Log',             // Added - 2011-06-17
     'ExportMiscFiles'      => 'Exportera andra filer (om dom finns)',
     'ExportOptions'        => 'Konfiguera export',
     'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
@@ -360,16 +367,21 @@ $SLANG = array(
     'Language'             => 'Sprk',
     'Last'                 => 'Sist',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Level'                => 'Level',                  // Added - 2011-06-16
     'LimitResultsPost'     => 'resultaten;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Begrnsa till frsta', // This is used at the beginning of the phrase 'Limit to first N results only'
+    'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Lnkade vervakare',
     'List'                 => 'Lista',
     'Load'                 => 'Belastning',
     'Local'                => 'Lokal',
+    'Log'                  => 'Log',                    // Added - 2011-06-16
     'LoggedInAs'           => 'Inloggad som',
+    'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Loggar in',
     'Login'                => 'Logga in',
     'Logout'               => 'Logga ut',
+    'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Lg',
     'LowBW'                => 'Lg bandbredd',
     'Main'                 => 'Huvudmeny',
@@ -403,6 +415,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Max ramar/s',
     'Medium'               => 'Mellan',
     'MediumBW'             => 'Mellan bandbredd',
+    'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minsta larmarean skall vara mindre n strsta',
     'MinAlarmAreaUnset'    => 'Du mste ange minsta antal larmbildpunkter',
     'MinBlobAreaLtMax'     => 'Minsta blobarean skall vara mindre n hgsta',
@@ -446,6 +459,7 @@ $SLANG = array(
     'Monitors'             => 'Bevakare',
     'Montage'              => 'Montera',
     'Month'                => 'Mnad',
+    'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Flytta',
     'MustBeGe'             => 'mste vara strre n eller lika med',
     'MustBeLe'             => 'mste vara mindre n eller lika med',
@@ -506,6 +520,7 @@ $SLANG = array(
     'Pause'                => 'Paus',
     'Phone'                => 'Mobil',
     'PhoneBW'              => 'Mobil bandbredd',
+    'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Skillnad i bildpunkter',
     'Pixels'               => 'bildpunkter',
     'Play'                 => 'Spela',
@@ -561,6 +576,8 @@ $SLANG = array(
     'Secs'                 => 'Sek',
     'Sectionlength'        => 'Sektionslngd',
     'Select'               => 'Vlj',
+    'SelectFormat'         => 'Select Format',          // Added - 2011-06-17
+    'SelectLog'            => 'Select Log',             // Added - 2011-06-17
     'SelectMonitors'       => 'Vlj bevakare',
     'SelfIntersecting'     => 'Polygonndarna fr inte verlappa',
     'Set'                  => 'Stll in',
@@ -603,6 +620,7 @@ $SLANG = array(
     'StreamReplayBuffer'   => 'Buffert fr strmmande uppspelning',
     'Submit'               => 'Skicka',
     'System'               => 'System',
+    'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Miniatyrer',
     'Tilt'                 => 'Tilt',
@@ -616,6 +634,7 @@ $SLANG = array(
     'TimestampLabelY'      => 'Vrde p tidsstmpel Y',
     'Today'                => 'Idag',
     'Tools'                => 'Verktyg',
+    'Total'                => 'Total',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Total<br/>Score',
     'TrackDelay'           => 'Sprfrdrjning',
     'TrackMotion'          => 'Spra rrelse',
@@ -630,6 +649,8 @@ $SLANG = array(
     'Update'               => 'Uppdatera',
     'UpdateAvailable'      => 'En uppdatering till ZoneMinder finns tillgnglig.',
     'UpdateNotNecessary'   => 'Ingen uppdatering behvs.',
+    'Updated'              => 'Updated',                // Added - 2011-06-16
+    'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Anvnd filter',
     'UseFilterExprsPost'   => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Anvnd&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
@@ -681,6 +702,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Min/Max blobbar',
     'ZoneMinMaxFiltArea'   => 'Min/Max filterarea',
     'ZoneMinMaxPixelThres' => 'Min/Max pixel Threshold (0-255)',
+    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
     'Zones'                => 'Zoner',
     'Zoom'                 => 'Zoom',
