@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web group detail view file, $Date: 2009-05-13 11:48:58 +0100 (Wed, 13 May 2009) $, $Revision: 2871 $
+// ZoneMinder web group detail view file, $Date: 2010-02-15 17:10:10 +0000 (Mon, 15 Feb 2010) $, $Revision: 3021 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -61,7 +61,7 @@ xhtmlHeaders( __FILE__, $SLANG['Group']." - ".$newGroup['Name'] );
                 <select name="newGroup[MonitorIds][]" size="4" multiple="multiple">
 <?php
     $monitors = dbFetchAll( "select Id,Name from Monitors order by Sequence asc" );
-    $monitorIds = array_flip( split( ',', $newGroup['MonitorIds'] ) );
+    $monitorIds = array_flip( explode( ',', $newGroup['MonitorIds'] ) );
     foreach ( $monitors as $monitor )
     {
         if ( visibleMonitor( $monitor['Id'] ) )
