@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web timeline view file, $Date: 2009-06-22 12:23:28 +0100 (Mon, 22 Jun 2009) $, $Revision: 2930 $
+// ZoneMinder web timeline view file, $Date: 2011-02-06 15:28:49 +0000 (Sun, 06 Feb 2011) $, $Revision: 3277 $
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -266,10 +266,6 @@ if ( $tree )
     appendDatetimeRange( $tree, $minTime, $maxTime );
 
     $filterQuery = parseTreeToQuery( $tree );
-    if ( $filterQuery )
-    {
-        $filterQuery = '&'.$filterQuery;
-    }
 }
 else
 {
@@ -412,7 +408,8 @@ foreach( dbFetchAll( $eventsSql ) as $event )
         else
         {
             $framesSql = "select FrameId,Delta,unix_timestamp(TimeStamp) as TimeT,Score from Frames where EventId = '".$event['Id']."' and Score > 0";
-            foreach( dbFetchAll( $framesSql ) as $frame )
+            $result = dbQuery( $framesSql );
+            while( $frame = dbFetchNext( $result ) )
             {
                 if ( $frame['Score'] == 0 )
                     continue;
@@ -808,7 +805,7 @@ xhtmlHeaders(__FILE__, $SLANG['Timeline'] );
   <div id="page">
     <div id="header">
       <div id="headerButtons">
-        <?= makePopupLink( '?view=events&page=1&filter=1'.$filterQuery, 'zmEvents', 'events', $SLANG['List'], canView( 'Events' ) ) ?>
+        <?= makePopupLink( '?view=events&amp;page=1'.htmlspecialchars($filterQuery), 'zmEvents', 'events', $SLANG['List'], canView( 'Events' ) ) ?>
         <a href="#" onclick="closeWindow();"><?= $SLANG['Close'] ?></a>
       </div>
       <h2><?= $SLANG['Timeline'] ?></h2>
@@ -816,7 +813,7 @@ xhtmlHeaders(__FILE__, $SLANG['Timeline'] );
     <div id="content" class="chartSize">
       <div id="topPanel" class="graphWidth">
         <div id="imagePanel">
-          <div id="image" class="imageHeight"><img id="imageSrc" class="imageWidth" src="graphics/transparent.gif" title="<?= $SLANG['ViewEvent'] ?>"/></div>
+          <div id="image" class="imageHeight"><img id="imageSrc" class="imageWidth" src="graphics/transparent.gif" alt="<?= $SLANG['ViewEvent'] ?>" title="<?= $SLANG['ViewEvent'] ?>"/></div>
         </div>
         <div id="dataPanel">
           <div id="textPanel">
