@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web watch feed view file, $Date: 2009-05-25 19:03:46 +0100 (Mon, 25 May 2009) $, $Revision: 2890 $
+// ZoneMinder web watch feed view file, $Date: 2011-02-06 16:04:11 +0000 (Sun, 06 Feb 2011) $, $Revision: 3281 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -27,10 +27,10 @@ if ( !canView( 'Stream' ) )
 $sql = "select C.*, M.* from Monitors as M left join Controls as C on (M.ControlId = C.Id ) where M.Id = '".dbEscape($_REQUEST['mid'])."'";
 $monitor = dbFetchOne( $sql );
 
-if ( isset($_REQUEST['control']) )
-    $control = validInt($_REQUEST['control']);
+if ( isset($_REQUEST['showControls']) )
+    $showControls = validInt($_REQUEST['showControls']);
 else
-    $control = (canView( 'Control' ) && ($monitor['DefaultView'] == 'Control'));
+    $showControls = (canView( 'Control' ) && ($monitor['DefaultView'] == 'Control'));
 
 $showPtzControls = ( ZM_OPT_CONTROL && $monitor['Controllable'] && canView( 'Control' ) );
 
@@ -41,10 +41,10 @@ else
 
 $connkey = generateConnKey();
 
-if ( ZM_STREAM_METHOD == 'mpeg' && ZM_MPEG_LIVE_FORMAT )
+if ( ZM_WEB_STREAM_METHOD == 'mpeg' && ZM_MPEG_LIVE_FORMAT )
 {
     $streamMode = "mpeg";
-    $streamSrc = getStreamSrc( array( "mode=".$streamMode, "monitor=".$monitor['Id'], "scale=".$scale, "bitrate=".ZM_WEB_VIDEO_BITRATE, "maxfps=".ZM_WEB_VIDEO_MAXFPS, "format=".ZM_MPEG_LIVE_FORMAT, "buffer=".$monitor['StreamReplayBuffer'] ) );
+    $streamSrc = getStreamSrc( array( "mode=".$streamMode, "monitor=".$monitor['Id'], "scale=".$scale, "bitrate=".ZM_WEB_VIDEO_BITRATE, "maxfps=".ZM_WEB_VIDEO_MAXFPS, "format=".ZM_MPEG_LIVE_FORMAT ) );
 }
 elseif ( canStream() )
 {
@@ -57,7 +57,7 @@ else
     $streamSrc = getStreamSrc( array( "mode=".$streamMode, "monitor=".$monitor['Id'], "scale=".$scale ) );
 }
 
-$showDvrControls = ( $streamMode != 'signal' && $monitor['StreamReplayBuffer'] != 0 );
+$showDvrControls = ( $streamMode == 'jpeg' && $monitor['StreamReplayBuffer'] != 0 );
 
 noCacheHeaders();
 
@@ -76,13 +76,13 @@ if ( $showPtzControls )
     if ( canView( 'Control' ) )
     {
 ?>
-          <div id="controlControl"<?= $control?' class="hidden"':'' ?>><a id="controlLink" href="#" onclick="showPtzControls(); return( false );"><?= $SLANG['Control'] ?></a></div>
+          <div id="controlControl"<?= $showControls?' class="hidden"':'' ?>><a id="controlLink" href="#" onclick="showPtzControls(); return( false );"><?= $SLANG['Control'] ?></a></div>
 <?php
     }
     if ( canView( 'Events' ) )
     {
 ?>
-          <div id="eventsControl"<?= $control?'':' class="hidden"' ?>><a id="eventsLink" href="#" onclick="showEvents(); return( false );"><?= $SLANG['Events'] ?></a></div>
+          <div id="eventsControl"<?= $showControls?'':' class="hidden"' ?>><a id="eventsLink" href="#" onclick="showEvents(); return( false );"><?= $SLANG['Events'] ?></a></div>
 <?php
     }
 }
@@ -91,7 +91,7 @@ if ( $showPtzControls )
 if ( canView( 'Control' ) && $monitor['Type'] == "Local" )
 {
 ?>
-          <div id="settingsControl"><?= makePopupLink( '?view=settings&mid='.$monitor['Id'], 'zmSettings'.$monitor['Id'], 'settings', $SLANG['Settings'], true, 'id="settingsLink"' ) ?></div>
+          <div id="settingsControl"><?= makePopupLink( '?view=settings&amp;mid='.$monitor['Id'], 'zmSettings'.$monitor['Id'], 'settings', $SLANG['Settings'], true, 'id="settingsLink"' ) ?></div>
 <?php
 }
 ?>
@@ -100,7 +100,7 @@ if ( canView( 'Control' ) && $monitor['Type'] == "Local" )
       </div>
       <div id="imageFeed">
 <?php
-if ( $streamMode === "mpeg" )
+if ( $streamMode == "mpeg" )
 {
     outputVideoStream( "liveStream", $streamSrc, reScale( $monitor['Width'], $scale ), reScale( $monitor['Height'], $scale ), ZM_MPEG_LIVE_FORMAT, $monitor['Name'] );
 }
@@ -157,7 +157,7 @@ if ( $showPtzControls )
     foreach ( getSkinIncludes( 'includes/control_functions.php' ) as $includeFile )
         require_once $includeFile;
 ?>
-      <div id="ptzControls" class="ptzControls<?= $control?'':' hidden' ?>">
+      <div id="ptzControls" class="ptzControls<?= $showControls?'':' hidden' ?>">
 <?= ptzControls( $monitor ) ?>
       </div>
 <?php
@@ -165,7 +165,7 @@ if ( $showPtzControls )
 if ( canView( 'Events' ) )
 {
 ?>
-      <div id="events"<?= $control?' class="hidden"':'' ?>>
+      <div id="events"<?= $showControls?' class="hidden"':'' ?>>
         <table id="eventList" cellspacing="0">
           <thead>
             <tr>
@@ -199,7 +199,7 @@ if ( ZM_WEB_SOUND_ON_ALARM )
           <param name="FileName" value="<?= $soundSrc ?>"/>
           <param name="autoStart" value="0"/>
           <param name="loop" value="1"/>
-          <param name=hidden value="1"/>
+          <param name="hidden" value="1"/>
           <param name="showControls" value="0"/>
           <embed src="<?= $soundSrc ?>"
             autostart="true"
