@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web console file, $Date: 2009-05-08 11:04:12 +0100 (Fri, 08 May 2009) $, $Revision: 2865 $
+// ZoneMinder web console file, $Date: 2010-02-23 09:10:36 +0000 (Tue, 23 Feb 2010) $, $Revision: 3030 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -43,7 +43,7 @@ $running = daemonCheck();
 $status = $running?$SLANG['Running']:$SLANG['Stopped'];
 
 if ( $group = dbFetchOne( "select * from Groups where Name = 'Mobile'" ) )
-    $groupIds = array_flip(split( ',', $group['MonitorIds'] ));
+    $groupIds = array_flip(explode( ',', $group['MonitorIds'] ));
 
 $maxWidth = 0;
 $maxHeight = 0;
@@ -86,7 +86,7 @@ xhtmlHeaders( __FILE__, $SLANG['Console'] );
 <body>
   <div id="page">
     <div id="header">
-      <div id="systemTime"><a href="?view=$view"><?= preg_match( '/%/', DATE_FMT_CONSOLE_SHORT )?strftime( DATE_FMT_CONSOLE_SHORT ):date( DATE_FMT_CONSOLE_SHORT ) ?></a></div>
+      <div id="systemTime"><a href="?view=<?= $view ?>"><?= preg_match( '/%/', DATE_FMT_CONSOLE_SHORT )?strftime( DATE_FMT_CONSOLE_SHORT ):date( DATE_FMT_CONSOLE_SHORT ) ?></a></div>
       <div id="systemStats"><?= getLoad() ?>/<?= getDiskPercent() ?>%</div>
       <div id="systemState"><?= makeLink( "?view=state", $status, canEdit( 'System' ) ) ?></div>
     </div>
